@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -47,6 +50,8 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.StringWriter;
 import java.io.Writer;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.HashMap;
@@ -123,6 +128,10 @@ public class MakeJNLP extends Task {
     public void setKeystore(String k) {
         getSignTask().setKeystore(k);
     }
+
+    public void setStoreType(String t) {
+        getSignTask().setStoretype(t);
+    }
     
     private String codebase = "$$codebase";
     public void setCodebase(String s) {
@@ -277,7 +286,7 @@ public class MakeJNLP extends Task {
             }
             
             JarFile theJar = new JarFile(jar);
-            String codenamebase = theJar.getManifest().getMainAttributes().getValue("OpenIDE-Module");
+            String codenamebase = JarWithModuleAttributes.extractCodeName(theJar.getManifest().getMainAttributes());
             if (codenamebase == null) {
                 throw new BuildException("Not a NetBeans Module: " + jar);
             }
@@ -327,7 +336,7 @@ public class MakeJNLP extends Task {
             
             StringWriter writeJNLP = new StringWriter();
             writeJNLP.write("<?xml version='1.0' encoding='UTF-8'?>\n");
-            writeJNLP.write("<!DOCTYPE jnlp PUBLIC \"-//Sun Microsystems, Inc//DTD JNLP Discriptor 1.5//EN\" \"http://java.sun.com/dtd/JNLP-1.5.dtd\">\n");
+            writeJNLP.write("<!DOCTYPE jnlp PUBLIC \"-//Sun Microsystems, Inc//DTD JNLP Descriptor 6.0//EN\" \"http://java.sun.com/dtd/JNLP-6.0.dtd\">\n");
             writeJNLP.write("<jnlp spec='1.0+' codebase='" + codebase + "'>\n");
             writeJNLP.write("  <information>\n");
             writeJNLP.write("   <title>" + XMLUtil.toElementContent(title) + "</title>\n");
@@ -460,6 +469,8 @@ public class MakeJNLP extends Task {
 
         fileToOwningModule.remove("ant/nblib/" + dashcnb + ".jar");
 
+        fileToOwningModule.remove("VERSION.txt"); // cluster release information
+
         fileToOwningModule.keySet().removeAll(indirectFilePaths);
         
         if (verifyExcludes != null) {
@@ -474,7 +485,7 @@ public class MakeJNLP extends Task {
             if (!fileToOwningModule.isEmpty()) {
                 throw new BuildException(
                     "Cannot build JNLP for module " + f + " as these files are in " +
-                    "module's NBM, but are not referenced from any path:\n" + fileToOwningModule.keySet()
+                    "module's NBM, but are not referenced from any path (see harness/README for properties you can define to fix):\n" + fileToOwningModule.keySet()
                 );
             }
         }
@@ -534,20 +545,20 @@ public class MakeJNLP extends Task {
             if (n.endsWith(".jar")) {
                 n = n.substring(0, n.length() - 4);
             }
-            
+            File ext = new File(new File(targetFile, dashcnb), s.replace("../", "").replace('/', '-'));
+
             if (isSigned(e) != null) {
                 Copy copy = (Copy)getProject().createTask("copy");
                 copy.setFile(e);
-                File t = new File(new File(targetFile, dashcnb), s.replace('/', '-'));
-                copy.setTofile(t);
+                copy.setTofile(ext);
                 copy.execute();
                 
-                String extJnlpName = dashcnb + '-' + t.getName().replaceFirst("\\.jar$", "") + ".jnlp";
+                String extJnlpName = dashcnb + '-' + ext.getName().replaceFirst("\\.jar$", "") + ".jnlp";
                 File jnlp = new File(targetFile, extJnlpName);
 
                 FileWriter writeJNLP = new FileWriter(jnlp);
                 writeJNLP.write("<?xml version='1.0' encoding='UTF-8'?>\n");
-                writeJNLP.write("<!DOCTYPE jnlp PUBLIC \"-//Sun Microsystems, Inc//DTD JNLP Discriptor 1.5//EN\" \"http://java.sun.com/dtd/JNLP-1.5.dtd\">\n");
+                writeJNLP.write("<!DOCTYPE jnlp PUBLIC \"-//Sun Microsystems, Inc//DTD JNLP Descriptor 6.0//EN\" \"http://java.sun.com/dtd/JNLP-6.0.dtd\">\n");
                 writeJNLP.write("<jnlp spec='1.0+' codebase='" + codebase + "'>\n");
                 writeJNLP.write("  <information>\n");
                 writeJNLP.write("    <title>" + n + "</title>\n");
@@ -555,7 +566,7 @@ public class MakeJNLP extends Task {
                 writeJNLP.write("  </information>\n");
                 writeJNLP.write(permissions +"\n");
                 writeJNLP.write("  <resources>\n");
-                writeJNLP.write(constructJarHref(t, dashcnb));
+                writeJNLP.write(constructJarHref(ext, dashcnb));
                 writeJNLP.write("  </resources>\n");
                 writeJNLP.write("  <component-desc/>\n");
                 writeJNLP.write("</jnlp>\n");
@@ -563,7 +574,6 @@ public class MakeJNLP extends Task {
                 
                 fileWriter.write("    <extension name='" + e.getName().replaceFirst("\\.jar$", "") + "' href='" + extJnlpName + "'/>\n");
             } else {
-                File ext = new File(new File(targetFile, dashcnb), s.replace('/', '-'));
                 signOrCopy(e, ext);
 
                 fileWriter.write(constructJarHref(ext, dashcnb));
@@ -637,11 +647,16 @@ public class MakeJNLP extends Task {
         signOrCopy(ext, null);
     }
 
-    private static String relative(File file, File root) {
+    private String relative(File file, File root) {
         String sfile = file.toString().replace(File.separatorChar, '/');
         String sroot = (root.toString() + File.separator).replace(File.separatorChar, '/');
         if (sfile.startsWith(sroot)) {
-            return sfile.substring(sroot.length());
+            try {
+                String result = new URI(null, sfile.substring(sroot.length()), null).normalize().getPath();
+                return result;
+            } catch (URISyntaxException x) {
+                throw new BuildException(x, getLocation()); // or just ignore?
+            }
         }
         return sfile;
     }
