@@ -25,12 +25,16 @@
 
 package com.sun.tools.visualvm.application.views.threads;
 
+import java.beans.PropertyChangeListener;
+import java.beans.PropertyChangeSupport;
 import java.lang.management.ThreadInfo;
 import java.lang.management.ThreadMXBean;
+import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Set;
 import java.util.logging.Logger;
+import org.netbeans.lib.profiler.client.MonitoredData;
 import org.netbeans.lib.profiler.global.CommonConstants;
 import org.netbeans.lib.profiler.wireprotocol.MonitoredNumbersResponse;
 import org.openide.util.RequestProcessor;
@@ -43,20 +47,40 @@ class ThreadMXBeanDataManager extends VisualVMThreadsDataManager {
 
     private static final long[] dummyLong = new long[0];
     private static final Logger LOGGER = Logger.getLogger(ThreadMXBeanDataManager.class.getName());
+    static final String DEADLOCK_PROP = "Deadlock";   // NOI18N
+    
     private ThreadMXBean threadBean;
     private Set<Long> threadIdSet = new HashSet();
     private boolean refreshRunning;
-
+    private DeadlockDetector deadlockDetector;
+    private PropertyChangeSupport changeSupport;
+    private long[] deadlockThreadIds;
+            
     ThreadMXBeanDataManager(ThreadMXBean tb) {
         threadBean = tb;
+        deadlockDetector = new DeadlockDetector(tb);
+        changeSupport = new PropertyChangeSupport(this);
     }
 
     // Non-blocking call for general usage
     void refreshThreadsAsync() {
-        if (refreshRunning) return;
-        refreshRunning = true;
+        synchronized (this) {
+            if (refreshRunning) return;
+            refreshRunning = true;
+        }
         RequestProcessor.getDefault().post(new Runnable() {
-            public void run() { refreshThreadsSync(); }
+            public void run() {
+                long[] oldDeadlockThreadIds = deadlockThreadIds;
+                
+                refreshThreadsSync();
+                deadlockThreadIds = deadlockDetector.detectDeadlock();
+                if (deadlockThreadIds != null && !Arrays.equals(oldDeadlockThreadIds,deadlockThreadIds)) {
+                    changeSupport.firePropertyChange(DEADLOCK_PROP,oldDeadlockThreadIds,deadlockThreadIds);
+                }
+                synchronized (ThreadMXBeanDataManager.this) {
+                   refreshRunning = false; 
+                }
+            }
         });
     }
 
@@ -65,11 +89,9 @@ class ThreadMXBeanDataManager extends VisualVMThreadsDataManager {
         try {
             ThreadMonitoredDataResponse resp = new ThreadMonitoredDataResponse();
             resp.fillInThreadData();
-            processData(org.netbeans.lib.profiler.client.MonitoredData.getMonitoredData(resp));
+            processData(MonitoredData.getMonitoredData(resp));
         } catch (Exception ex) {
             LOGGER.throwing(ThreadMXBeanDataManager.class.getName(), "refreshThreads", ex); // NOI18N
-        } finally {
-            refreshRunning = false;
         }
     }
 
@@ -80,7 +102,15 @@ class ThreadMXBeanDataManager extends VisualVMThreadsDataManager {
     int getThreadCount() {
         return threadBean.getThreadCount();
     }
-
+    
+    void addPropertyChangeListener(PropertyChangeListener l) {
+         changeSupport.addPropertyChangeListener(l);
+    }
+    
+    void removePropertyChangeListener(PropertyChangeListener l) {
+        changeSupport.removePropertyChangeListener(l);
+    }
+    
     class ThreadMonitoredDataResponse extends MonitoredNumbersResponse {
 
         ThreadMonitoredDataResponse() {
@@ -160,4 +190,4 @@ class ThreadMXBeanDataManager extends VisualVMThreadsDataManager {
                     "sleep".equals(element.getMethodName());    // NOI18N
         }
     }
-}
\ No newline at end of file
+}
