@@ -66,11 +66,11 @@ final class Separator extends JSeparator {
     }
 
 
-    public Separator() {
+    Separator() {
         super();
     }
 
-    public Separator(int orientation) {
+    Separator(int orientation) {
         super(orientation);
     }
 
