@@ -1,12 +1,12 @@
 /*
- * Copyright 2007-2010 Sun Microsystems, Inc.  All Rights Reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.  Sun designates this
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the LICENSE file that accompanied this code.
+ * by Oracle in the LICENSE file that accompanied this code.
  *
  * This code is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -18,9 +18,9 @@
  * 2 along with this work; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Please contact Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
- * CA 95054 USA or visit www.sun.com if you need additional information or
- * have any questions.
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package com.sun.tools.visualvm.jmx.impl;
@@ -62,6 +62,7 @@ import java.util.Properties;
 import java.util.StringTokenizer;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+import javax.management.ListenerNotFoundException;
 import javax.management.MBeanServerConnection;
 import javax.management.Notification;
 import javax.management.NotificationListener;
@@ -520,16 +521,14 @@ class JmxModelImpl extends JmxModel {
             // Close MBeanServer connection
             if (jmxc != null) {
                 try {
+                    jmxc.removeConnectionNotificationListener(this);
                     if (sendClose) jmxc.close();
                 } catch (IOException e) {
                     // Ignore...
-                } finally {
-                    try {
-                        jmxc.removeConnectionNotificationListener(this);
-                    } catch (Exception e) {
-                        // Ignore...
-                    }
+                } catch (ListenerNotFoundException e) {
+                     LOGGER.log(Level.INFO, "disconnectImpl", e); // NOI18N                   
                 }
+                jmxc = null;
             }
             // Set connection state to DISCONNECTED
             if (!isDead) {
