@@ -1,12 +1,12 @@
 /*
- * Copyright 2007-2010 Sun Microsystems, Inc.  All Rights Reserved.
+ * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 only, as
- * published by the Free Software Foundation.  Sun designates this
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the LICENSE file that accompanied this code.
+ * by Oracle in the LICENSE file that accompanied this code.
  *
  * This code is distributed in the hope that it will be useful, but WITHOUT
  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -18,9 +18,9 @@
  * 2 along with this work; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Please contact Sun Microsystems, Inc., 4150 Network Circle, Santa Clara,
- * CA 95054 USA or visit www.sun.com if you need additional information or
- * have any questions.
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package com.sun.tools.visualvm.jvm;
@@ -143,6 +143,14 @@ public class JVMImpl extends Jvm implements JvmstatListener {
         initStaticData();
         return vmVersion;
     }
+
+    public String getJavaVersion() {
+        initStaticData();
+        if (javaVersion != null) {
+            return javaVersion;
+        }
+        return vmVersion;
+    }
     
     public String getJavaHome() {
         initStaticData();
@@ -174,9 +182,6 @@ public class JVMImpl extends Jvm implements JvmstatListener {
     
     public boolean is15() {
         String ver = getJavaVersion();
-        if (ver == null) {
-           ver = getVmVersion();
-        }
         if (ver != null && ver.startsWith("1.5.")) {    // NOI18N
             return true;
         }
@@ -185,9 +190,6 @@ public class JVMImpl extends Jvm implements JvmstatListener {
     
     public boolean is16() {
         String ver = getJavaVersion();
-        if (ver == null) {
-           ver = getVmVersion();
-        }
         if (ver != null && (ver.startsWith("1.6.") || ver.startsWith("10.") || ver.startsWith("11."))) {    // NOI18N
             return true;
         }
@@ -196,9 +198,6 @@ public class JVMImpl extends Jvm implements JvmstatListener {
     
     public boolean is17() {
         String ver = getJavaVersion();
-        if (ver == null) {
-           ver = getVmVersion();
-        }
         if (ver != null && (ver.startsWith("1.7.") || ver.startsWith("12.") || ver.startsWith("13.") || ver.startsWith("14."))) {  // NOI18N
             return true;
         }
@@ -498,11 +497,6 @@ public class JVMImpl extends Jvm implements JvmstatListener {
         }
         return args;
     }
-
-    private String getJavaVersion() {
-        initStaticData();
-        return javaVersion;
-    }
     
     public void dataChanged(JvmstatModel stat) {
         assert stat == monitoredVm;
