@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -112,10 +115,23 @@ void set_system_loader(JNIEnv *env, jvmtiEnv *jvmti_env) {
   
     (*jvmti_env)->GetPhase(jvmti_env, &phase);
     if (phase >= JVMTI_PHASE_LIVE) {  /* Call ClassLoader.getSystemClassLoader() */
+        jthrowable ex;
         jclass class_loader_clazz = (*env)->FindClass(env, "java/lang/ClassLoader");
         jmethodID get_system_loader_method = (*env)->GetStaticMethodID(env, class_loader_clazz, "getSystemClassLoader", "()Ljava/lang/ClassLoader;");
         
         _system_loader = (*env)->CallStaticObjectMethod(env, class_loader_clazz, get_system_loader_method);
+        ex = (*env)->ExceptionOccurred(env);
+        if (ex != NULL) {
+            jclass ise_cls;
+            
+            (*env)->ExceptionClear(env);
+            ise_cls = (*env)->FindClass(env, "java/lang/IllegalStateException");
+            if (!(*env)->IsInstanceOf(env, ex, ise_cls)) {
+                fprintf(stderr, "Profiler Agent Error: Exception from ClassLoader.getSystemClassLoader()\n");
+            }
+            _system_loader = NULL;
+            return;
+        }
         _system_loader = (*env)->NewGlobalRef(env, _system_loader);
         
         /* Create a lock object used to synchronize access to _ctable */
@@ -135,7 +151,7 @@ int loader_is_system_loader(JNIEnv *jni_env, jvmtiEnv *jvmti_env, jobject loader
         set_system_loader(jni_env, jvmti_env);
     }
     if (_system_loader == NULL) {
-        return 0;
+        return 1;
     }
     if ((*jni_env)->IsSameObject(jni_env, loader, _system_loader)) {
         return 1;
