@@ -28,6 +28,8 @@ package com.sun.tools.visualvm.sampler.cpu;
 import com.sun.tools.visualvm.core.options.GlobalPreferences;
 import com.sun.tools.visualvm.core.ui.components.DataViewComponent;
 import com.sun.tools.visualvm.sampler.AbstractSamplerSupport;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
 import java.lang.management.ThreadInfo;
 import java.util.HashSet;
 import java.util.Set;
@@ -66,9 +68,14 @@ public abstract class CPUSamplerSupport extends AbstractSamplerSupport {
     private CPUView cpuView;
     private DataViewComponent.DetailsView[] detailsViews;
 
+    private javax.swing.Timer threadCPUTimer;
+    private Refresher threadCPURefresher;
+    private ThreadsCPUView threadCPUView;
+    private ThreadsCPU threadsCPU;
 
-    public CPUSamplerSupport(ThreadInfoProvider tip, SnapshotDumper snapshotDumper, ThreadDumper threadDumper) {
+    public CPUSamplerSupport(ThreadInfoProvider tip, ThreadsCPU tcpu, SnapshotDumper snapshotDumper, ThreadDumper threadDumper) {
         threadInfoProvider = tip;
+        threadsCPU = tcpu;
         this.snapshotDumper = snapshotDumper;
         this.threadDumper = threadDumper;
 
@@ -94,12 +101,20 @@ public abstract class CPUSamplerSupport extends AbstractSamplerSupport {
     public DataViewComponent.DetailsView[] getDetailsView() {
         if (detailsViews == null) {
             cpuView = new CPUView(refresher, snapshotDumper, threadDumper);
-                        detailsViews = new DataViewComponent.DetailsView[] {
-                new DataViewComponent.DetailsView(NbBundle.getMessage(
-                CPUSamplerSupport.class, "LBL_Cpu_samples"), null, 10, cpuView, null) }; // NOI18N
+            detailsViews = new DataViewComponent.DetailsView[threadsCPU != null ? 2:1];
+            detailsViews[0] = new DataViewComponent.DetailsView(NbBundle.getMessage(
+                CPUSamplerSupport.class, "LBL_Cpu_samples"), null, 10, cpuView, null); // NOI18N
+            if (threadsCPU != null) {
+                threadCPUView = new ThreadsCPUView(refresher);
+                detailsViews[1] = new DataViewComponent.DetailsView(NbBundle.getMessage(
+                CPUSamplerSupport.class, "LBL_ThreadAlloc"), null, 20, threadCPUView, null); // NOI18N
+                
+            }
         }
-
         cpuView.initSession();
+        if (threadsCPU != null) {
+            threadCPUView.initSession();
+        }
         return detailsViews.clone();
     }
 
@@ -122,12 +137,35 @@ public abstract class CPUSamplerSupport extends AbstractSamplerSupport {
         if (timer == null) timer = getTimer();
         samplerTask = new SamplerTask(builder);
 
-        try {
-            timer.scheduleAtFixedRate(samplerTask, 0, samplingRate);
-            return true;
-        } catch (Exception e) {
-            return false;
+        timer.scheduleAtFixedRate(samplerTask, 0, samplingRate);
+        
+        if (threadsCPU != null) {
+            threadCPUTimer = new javax.swing.Timer(refreshRate, new ActionListener() {
+                public void actionPerformed(ActionEvent e) {
+                    threadCPURefresher.refresh();
+                }
+            });
+            threadCPURefresher = new Refresher() {
+                public final boolean checkRefresh() {
+                    if (!threadCPUTimer.isRunning()) return false;
+                    return threadCPUView.isShowing();
+                }
+                public final void doRefresh() {
+                    doRefreshImpl(threadCPUTimer, threadCPUView);
+                }
+                public final void setRefreshRate(int refreshRate) {
+                    threadCPUTimer.setDelay(refreshRate);
+                    threadCPUTimer.setInitialDelay(refreshRate);
+                    threadCPUTimer.restart();
+                }
+                public final int getRefreshRate() {
+                    return threadCPUTimer.getDelay();
+                }
+            };
+
+            threadCPURefresher.setRefreshRate(refreshRate);
         }
+        return true;
     }
 
     public synchronized void stopSampling() {
@@ -135,6 +173,10 @@ public abstract class CPUSamplerSupport extends AbstractSamplerSupport {
             samplerTask.cancel();
             samplerTask = null;
         }
+        if (threadCPUTimer != null) {
+            threadCPUTimer.stop();
+            threadCPUTimer = null;
+        }
     }
 
     public synchronized void terminate() {
@@ -143,6 +185,7 @@ public abstract class CPUSamplerSupport extends AbstractSamplerSupport {
             timer = null;
         }
         if (cpuView != null) cpuView.terminate();
+        if (threadCPUView != null) threadCPUView.terminate();
     }
 
 
@@ -161,6 +204,32 @@ public abstract class CPUSamplerSupport extends AbstractSamplerSupport {
             }
         });
     }
+    private void doRefreshImpl(final javax.swing.Timer stimer, final ThreadsCPUView view) {
+        if (!stimer.isRunning() || view.isPaused()) return;
+        
+        try {
+            timer.schedule(new TimerTask() {
+                public void run() {
+                    try {
+                        if (!stimer.isRunning()) return;
+                        doRefreshImplImpl(threadsCPU.getThreadsCPUInfo(), view);
+                    } catch (Exception e) {
+                        terminate();
+                    }
+                }
+            }, 0);
+        } catch (Exception e) {
+            terminate();
+        }
+    }
+    
+    private void doRefreshImplImpl(final ThreadsCPUInfo info, final ThreadsCPUView view) {
+            SwingUtilities.invokeLater(new Runnable() {
+                public void run() {
+                    view.refresh(info);
+                }
+            });
+    }
 
     private int convertFilterType(int simpleFilterrType) {
         if (simpleFilterrType == SimpleFilter.SIMPLE_FILTER_NONE) {
@@ -187,8 +256,8 @@ public abstract class CPUSamplerSupport extends AbstractSamplerSupport {
 
         public void run() {
             if (sampleRunning) return;
+            sampleRunning = true;
             synchronized (updateLock) {
-                sampleRunning = true;
                 try {
                     ThreadInfo[] infos = threadInfoProvider.dumpAllThreads();
                     long timestamp = System.nanoTime();
