@@ -102,7 +102,7 @@ public class DynamicClassInfo extends ClassInfo {
         byte[] classFileBytes = getClassFileBytes();
 
         try {
-            (new ClassFileParser()).parseClassFile(classFileBytes, this);
+            new ClassFileParser().parseClassFile(classFileBytes, this);
 
             if (!className.equals(name)) {
                 throw new ClassFormatError("Mismatch between name in .class file and location for " + className // NOI18N
@@ -444,8 +444,8 @@ public class DynamicClassInfo extends ClassInfo {
 
     public void addSubclass(DynamicClassInfo subclass) {
         if (subclasses == null) {
-            if (name == "java/lang/Object") {
-                subclasses = new ArrayList(500); // NOI18N
+            if (name == "java/lang/Object") {  // NOI18N
+                subclasses = new ArrayList(500);
             } else {
                 subclasses = new ArrayList();
             }
@@ -500,8 +500,8 @@ public class DynamicClassInfo extends ClassInfo {
 
         DynamicClassInfo superClass = getSuperClass();
 
-        if ((superClass == null) || (superClass.getName() == "java/lang/Object")) {
-            return false; // NOI18N
+        if ((superClass == null) || (superClass.getName() == "java/lang/Object")) {  // NOI18N
+            return false;
         }
 
         return superClass.implementsInterface(intfName);
