@@ -117,20 +117,28 @@ public class IntegrationUtils {
                                                              boolean formatAsHTML) {
         return getExportEnvVariableValueString(targetPlatform, getNativePathEnvVariableString(targetPlatform),
                                                getNativeLibrariesPath(targetPlatform, targetJVM, isRemote)
-                                               + getPathSeparator(targetPlatform)
+                                               + getClassPathSeparator(targetPlatform)
                                                + getEnvVariableReference(getNativePathEnvVariableString(targetPlatform),
                                                                          targetPlatform), formatAsHTML);
     }
 
     public static String getAssignEnvVariableValueString(String targetPlatform, String variableName, String variableValue) {
+        variableValue = variableValue.trim();
         if (isWindowsPlatform(targetPlatform)) {
             return getExportCommandString(targetPlatform) + " " + variableName + "=" + variableValue; //NOI18N
         }
 
-        return variableName + "=" + variableValue; //NOI18N
+        return variableName + "=" + (variableValue.contains(" ") ? "\"" + variableValue + "\"" : variableValue); //NOI18N
     }
 
     // Returns batch file extension bat / sh according to current / selected OS
+    public static String getBatchExtensionString(String targetPlatform, String customExt) {
+        if (isWindowsPlatform(targetPlatform)) {
+            return customExt + ".bat"; //NOI18N
+        }
+        return customExt + ".sh"; //NOI18N
+    }
+
     public static String getBatchExtensionString(String targetPlatform) {
         if (isWindowsPlatform(targetPlatform)) {
             return ".bat"; //NOI18N
@@ -355,7 +363,7 @@ public class IntegrationUtils {
     }
 
     public static String getManualRemoteStep2(String targetOS, String targetJVM) {
-        return MessageFormat.format(MANUAL_REMOTE_STEP2_MESSAGE, new Object[] { getRemoteCalibrateCommandString(targetOS) }); //NOI18N
+        return MessageFormat.format(MANUAL_REMOTE_STEP2_MESSAGE, new Object[] { getRemoteCalibrateCommandString(targetOS, targetJVM) }); //NOI18N
     }
 
     // Returns getLibsDir()/deployed/jdk<15>/<OS> appropriate for current / selected OS
@@ -399,8 +407,11 @@ public class IntegrationUtils {
         return null;
     }
 
-    // Returns ";" or ":" according to provided platform
-    public static String getPathSeparator(String targetPlatform) {
+    /**
+     * The separator used in the classpath construction
+     * @return Returns ";" or ":" according to provided platform
+     */ 
+    public static String getClassPathSeparator(String targetPlatform) {
         if (isWindowsPlatform(targetPlatform)) {
             return ";"; //NOI18N
         }
@@ -442,9 +453,16 @@ public class IntegrationUtils {
     // Returns extra command line arguments without additional quotes required when attaching on startup
     public static String getProfilerAgentCommandLineArgsWithoutQuotes(String targetPlatform, String targetJVM, boolean isRemote,
                                                                       int portNumber) {
-        return "-agentpath:" + getNativeLibrariesPath(targetPlatform, targetJVM, isRemote)
-               + getDirectorySeparator(targetPlatform) + getProfilerAgentLibraryFile(targetPlatform) + "=" //NOI18N
-               + getLibsDir(targetPlatform, isRemote) + "," + portNumber; //NOI18N
+        StringBuilder args = new StringBuilder();
+        
+        if ((targetJVM.equals(PLATFORM_JAVA_60) || targetJVM.equals(PLATFORM_JAVA_70)) && 
+            (targetPlatform.equals(PLATFORM_LINUX_OS) || targetPlatform.equals(PLATFORM_LINUX_AMD64_OS))) {
+            args.append(" -XX:+UseLinuxPosixThreadCPUClocks "); // NOI18N
+        }
+        args.append("-agentpath:").append(getNativeLibrariesPath(targetPlatform, targetJVM, isRemote)). // NOI18N
+               append(getDirectorySeparator(targetPlatform)).append(getProfilerAgentLibraryFile(targetPlatform)).append("="). //NOI18N
+               append(getLibsDir(targetPlatform, isRemote)).append(",").append(portNumber); //NOI18N
+        return args.toString();
     }
 
     // Returns filename of profiler agent library
@@ -463,7 +481,7 @@ public class IntegrationUtils {
     }
 
     public static String getProfilerModifiedReplaceFileHeader(String targetPlatform) {
-        return getProfilerModifiedFileHeader(targetPlatform) + getSilentScriptCommentSign(targetPlatform) + " "
+        return getProfilerModifiedFileHeader(targetPlatform) + getSilentScriptCommentSign(targetPlatform) + " " // NOI18N
                + ORIGINAL_BACKUP_LOCATION_STRING + getLineBreak(targetPlatform); //NOI18N
     }
 
@@ -472,15 +490,17 @@ public class IntegrationUtils {
     }
 
     // Returns calibration batch filename
-    public static String getRemoteCalibrateCommandString(String targetPlatform) {
-        return HTML_REMOTE_STRING + getDirectorySeparator(targetPlatform) + "bin" + getDirectorySeparator(targetPlatform)
-               + "calibrate" + getBatchExtensionString(targetPlatform); //NOI18N
+    public static String getRemoteCalibrateCommandString(String targetPlatform, String targetJava) {
+        String customExt = isLinuxPlatform(targetPlatform) ? (PLATFORM_JAVA_60.equals(targetJava) ? "-16" : "-15") : ""; // NOI18N
+        return HTML_REMOTE_STRING + getDirectorySeparator(targetPlatform) + "bin" + getDirectorySeparator(targetPlatform) // NOI18N
+               + "calibrate" + getBatchExtensionString(targetPlatform,  customExt); //NOI18N
     }
 
     // Returns profile batch filename
-    public static String getRemoteProfileCommandString(String targetPlatform) {
-        return HTML_REMOTE_STRING + getDirectorySeparator(targetPlatform) + "bin" + getDirectorySeparator(targetPlatform)
-               + "profile" + getBatchExtensionString(targetPlatform); //NOI18N
+    public static String getRemoteProfileCommandString(String targetPlatform, String targetJava) {
+        String customExt = PLATFORM_JAVA_50.equals(targetJava) ? "-15" : "-16"; // NOI18N
+        return HTML_REMOTE_STRING + getDirectorySeparator(targetPlatform) + "bin" + getDirectorySeparator(targetPlatform) // NOI18N
+               + "profile" + getBatchExtensionString(targetPlatform, customExt); //NOI18N
     }
 
     // returns "rem" or "#" according to provided platform
@@ -509,6 +529,10 @@ public class IntegrationUtils {
         return targetPlatform.equals(PLATFORM_WINDOWS_OS) || targetPlatform.equals(PLATFORM_WINDOWS_AMD64_OS);
     }
 
+    public static boolean isLinuxPlatform(String targetPlatform) {
+        return targetPlatform.equals(PLATFORM_LINUX_OS) || targetPlatform.equals(PLATFORM_LINUX_AMD64_OS);
+    }
+
     public static String getXMLCommendEndSign() {
         return "-->"; //NOI18N
     }
@@ -551,12 +575,17 @@ public class IntegrationUtils {
             target = new File(source.getAbsolutePath() + FILE_BACKUP_EXTENSION);
 
             FileChannel sourceChannel = new FileOutputStream(source).getChannel();
-            FileChannel targetChannel = new FileInputStream(target).getChannel();
-            targetChannel.transferTo(0, targetChannel.size(), sourceChannel);
-            targetChannel.close();
-            sourceChannel.close();
-
-            return true;
+            try {
+                FileChannel targetChannel = new FileInputStream(target).getChannel();
+                try {
+                    targetChannel.transferTo(0, targetChannel.size(), sourceChannel);
+                    return true;
+                } finally {
+                    targetChannel.close();
+                }
+            } finally {
+                sourceChannel.close();
+            }
         } catch (Exception ex) {
             ProfilerLogger.severe(MessageFormat.format(BACKUP_ERROR_COPY_FILE_MESSAGE,
                                                        new Object[] { target.getAbsolutePath(), source.getAbsolutePath(), ex })); //NOI18N
@@ -583,12 +612,17 @@ public class IntegrationUtils {
 
         try {
             FileChannel sourceChannel = new FileInputStream(sourceFile).getChannel();
-            FileChannel destinationChannel = new FileOutputStream(targetFile).getChannel();
-            sourceChannel.transferTo(0, sourceChannel.size(), destinationChannel);
-            sourceChannel.close();
-            destinationChannel.close();
-
-            return true;
+            try {
+                FileChannel destinationChannel = new FileOutputStream(targetFile).getChannel();
+                try {
+                    sourceChannel.transferTo(0, sourceChannel.size(), destinationChannel);
+                    return true;
+                } finally {
+                    destinationChannel.close();
+                }
+            } finally {
+                sourceChannel.close();                
+            }
         } catch (Exception ex) {
             ProfilerLogger.log(ex);
             ProfilerLogger.severe(MessageFormat.format(COPY_ERROR_MESSAGE,
