@@ -288,7 +288,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
                     try {
                         execInSeparateThreadLock.wait();
                     } catch (InterruptedException ex) {
-                        System.err.println(THREAD_WAIT_EXCEPTION_MSG); // NOI18N
+                        System.err.println(THREAD_WAIT_EXCEPTION_MSG);
                     }
 
                     if (stopped) {
@@ -362,8 +362,8 @@ public class ProfilerServer extends Thread implements CommonConstants {
     private static String INCORRECT_AGENT_ID_MSG = "Profiler Agent Warning: Wrong agentId specified: {0}"; // NOI18N
     private static String THREAD_EXCEPTION_MSG = "Profiler Agent Error: Exception in executeInSeparateThread()"; // NOI18N
     private static String THREAD_WAIT_EXCEPTION_MSG = "Profiler Agent Error: Exception in wait in SeparateCmdExecutionThread"; // NOI18N
-    private static String LOCAL_SESSION_MSG = "Profiler Agent: Local accelerated session";
-    private static String REMOTE_SESSION_MSG = "Profiler Agent: Standard session";
+    private static String LOCAL_SESSION_MSG = "Profiler Agent: Local accelerated session"; // NOI18N
+    private static String REMOTE_SESSION_MSG = "Profiler Agent: Standard session"; // NOI18N
     
     public static final int ATTACH_DYNAMIC = 0;
     public static final int ATTACH_DIRECT = 1;
@@ -410,6 +410,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
     private WireIO wireIO;
     private boolean dynamic;
     private int agentId = -1;
+    final private Random r = new Random(System.currentTimeMillis()) ;
 
     //---------------------------------------------------------------------------------------
     // Communication management
@@ -761,12 +762,11 @@ public class ProfilerServer extends Thread implements CommonConstants {
             try {
                 messages = getProfilerServerResourceBundle(_fullJFluidPath);
             } catch (Exception e) {
-                System.err.println("Profiler Server: Problem with customized initializing localized messages...\n"
-                                   + e.getMessage()); // NOI18N
+                System.err.println("Profiler Server: Problem with customized initializing localized messages...\n" + e.getMessage()); // NOI18N
             }
         }
 
-        ; // cannot find jfluid-server.jar or Bundle.properties not found
+        // cannot find jfluid-server.jar or Bundle.properties not found
 
         if (messages != null) {
             return messages; // ResourceBundle successfuly loaded using custom classloader
@@ -779,8 +779,6 @@ public class ProfilerServer extends Thread implements CommonConstants {
             System.err.println("Profiler Server: Problem with default initializing localized messages...\n" + e.getMessage()); // NOI18N
         }
 
-        ;
-
         return messages;
     }
 
@@ -832,7 +830,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
     private static File getInfoFile(int port) throws IOException {
         String dirName = Platform.getProfilerUserDir();
 
-        return new File(dirName + File.separator + port); // NOI18N
+        return new File(dirName + File.separator + port);
     }
 
     private static void setShutdownOK() {
@@ -979,7 +977,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
             // ignore
         }
 
-        System.out.println(ENTER_TO_SHUTDOWN_MSG); // NOI18N
+        System.out.println(ENTER_TO_SHUTDOWN_MSG);
 
         try {
             System.in.read();
@@ -1005,8 +1003,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         // can not access a member of class Test with modifiers "public static"". Thus we have to run the below preemptive check. Hope this is not
         // a problem for the majority of our users...
         if (!Modifier.isPublic(targetMainClass.getModifiers())) {
-            startupException = new IllegalAccessException(MessageFormat.format(MAIN_CLASS_NOT_PUBLIC_MSG,
-                                                                               new Object[] { targetMainClass })); // NOI18N
+            startupException = new IllegalAccessException(MessageFormat.format(MAIN_CLASS_NOT_PUBLIC_MSG, new Object[] { targetMainClass }));
             System.err.println(startupException);
 
             return;
@@ -1028,8 +1025,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         int mod = targetMainMethod.getModifiers();
 
         if (!(Modifier.isPublic(mod) && Modifier.isStatic(mod)) || Modifier.isAbstract(mod) || Modifier.isInterface(mod)) {
-            startupException = new IllegalAccessException(MessageFormat.format(INCORRECT_MAIN_MODIFIERS_MSG,
-                                                                               new Object[] { targetMainClass })); // NOI18N
+            startupException = new IllegalAccessException(MessageFormat.format(INCORRECT_MAIN_MODIFIERS_MSG, new Object[] { targetMainClass }));
             System.err.println(startupException);
 
             return;
@@ -1063,7 +1059,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
             }
         } catch (Throwable ex) {
             ProfilerInterface.disableProfilerHooks();
-            internalError(MessageFormat.format(UNEXPECTED_EXCEPTION_MSG, new Object[] { ex }), false); // NOI18N
+            internalError(MessageFormat.format(UNEXPECTED_EXCEPTION_MSG, new Object[] { ex }), false);
             ex.printStackTrace(System.err);
         } finally {
             int elapsedTime = (int) (((Timers.getCurrentTimeInCounts() - startTime) * 1000) / Timers.getNoOfCountsInSecond());
@@ -1105,13 +1101,13 @@ public class ProfilerServer extends Thread implements CommonConstants {
                 try {
                     agentId = Integer.parseInt(id);
                 } catch (NumberFormatException e) {
-                    System.err.println(MessageFormat.format(INCORRECT_AGENT_ID_MSG, new Object[] { id })); // NOI18N
+                    System.err.println(MessageFormat.format(INCORRECT_AGENT_ID_MSG, new Object[] { id }));
                                                                                                            // ignore, the agentId will be generated randomly
                 }
             }
 
             if (agentId == -1) {
-                agentId = (int) (Math.random() * (float) Integer.MAX_VALUE);
+                agentId = r.nextInt(Integer.MAX_VALUE);
             }
         }
 
@@ -1202,7 +1198,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         }
 
         try {
-            if (!jfluidServerJar.startsWith("/")) {
+            if (!jfluidServerJar.startsWith("/")) { // NOI18N
                 jfluidServerJar = "/" + jfluidServerJar; // NOI18N
             }
 
@@ -1210,9 +1206,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
             URLClassLoader loader = new URLClassLoader(new URL[] { new URL(bundleJarURLPath) });
             bundle = ResourceBundle.getBundle("org.netbeans.lib.profiler.server.Bundle", Locale.getDefault(), loader); // NOI18N
         } catch (Exception e2) {
-            throw new RuntimeException("ProfilerServer: Unable to initialize ResourceBundle for ProfilerServer\n"
-                                       + e2.getMessage() // NOI18N
-            );
+            throw new RuntimeException("ProfilerServer: Unable to initialize ResourceBundle for ProfilerServer\n" + e2.getMessage()); // NOI18N
         }
 
         if (bundle == null) {
@@ -1247,18 +1241,15 @@ public class ProfilerServer extends Thread implements CommonConstants {
         try {
             if (serverTimeout == 0) {
                 System.out.println(MessageFormat.format(WAITING_ON_PORT_MSG,
-                                                        new Object[] {
-                                                            "" + serverPort, // NOI18N
-                "" + CommonConstants.CURRENT_AGENT_VERSION // NOI18N
+                                                        new Object[] { "" + serverPort, // NOI18N
+                                                                       "" + CommonConstants.CURRENT_AGENT_VERSION // NOI18N
                                                         }));
             } else {
                 System.out.println(MessageFormat.format(WAITING_ON_PORT_TIMEOUT_MSG,
-                                                        new Object[] {
-                                                            "" + serverPort, // NOI18N
-                "" + serverTimeout, // NOI18N
-                "" + CommonConstants.CURRENT_AGENT_VERSION
-                                                        } // NOI18N
-                )); // NOI18N
+                                                        new Object[] { "" + serverPort, // NOI18N
+                                                                       "" + serverTimeout, // NOI18N
+                                                                       "" + CommonConstants.CURRENT_AGENT_VERSION // NOI18N
+                                                        }));
             }
 
             serverSocket = new ServerSocket(serverPort);
@@ -1273,10 +1264,10 @@ public class ProfilerServer extends Thread implements CommonConstants {
             System.out.println(CONNECTION_MSG);
             return true;
         } catch (SocketTimeoutException ex) {
-            System.err.println(CONNECTION_TIMEOUT_MSG); // NOI18N
+            System.err.println(CONNECTION_TIMEOUT_MSG);
             connectionFailed = true;
         } catch (IOException ex) {
-            System.err.println(MessageFormat.format(CONNECTION_EXCEPTION_MSG, new Object[] { ex })); // NOI18N
+            System.err.println(MessageFormat.format(CONNECTION_EXCEPTION_MSG, new Object[] { ex }));
             connectionFailed = true;
         } finally {
             //removeInfoFile ();
@@ -1306,7 +1297,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
 
             bos.close();
         } catch (IOException e) {
-            System.err.println(MessageFormat.format(AGENT_ERROR_MSG, new Object[] { e.getMessage() })); // NOI18N
+            System.err.println(MessageFormat.format(AGENT_ERROR_MSG, new Object[] { e.getMessage() }));
         } finally {
             if (bos != null) {
                 try {
@@ -1331,7 +1322,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
             try {
                 execInSeparateThreadLock.notify();
             } catch (IllegalMonitorStateException ex) {
-                System.err.println(THREAD_EXCEPTION_MSG); // NOI18N
+                System.err.println(THREAD_EXCEPTION_MSG);
             }
         }
     }
@@ -1371,8 +1362,8 @@ public class ProfilerServer extends Thread implements CommonConstants {
                         try {
                             targetAppRunningLock.wait();
                         } catch (InterruptedException ex) {
-                            internalError("START_TARGET_APP");
-                        } // NOI18N
+                            internalError("START_TARGET_APP"); // NOI18N
+                        }
                     }
 
                     if (startupException != null) {
@@ -1452,15 +1443,22 @@ public class ProfilerServer extends Thread implements CommonConstants {
 
                 break;
             case Command.SET_CHANGEABLE_INSTR_PARAMS:
-
+                boolean threadSampling;
+                boolean waitTracking;
+                boolean sleepTracking;
                 SetChangeableInstrParamsCommand scipCmd = (SetChangeableInstrParamsCommand) cmd;
                 ProfilerRuntimeCPU.setNProfiledThreadsLimit(scipCmd.getNProfiledThreadsLimit());
                 ProfilerRuntimeCPUSampledInstr.setSamplingInterval(scipCmd.getSamplingInterval());
                 ProfilerRuntimeMemory.setSamplingInterval((short) scipCmd.getObjAllocStackSamplingInterval());
                 ProfilerRuntimeMemory.setSamplingDepth(scipCmd.getObjAllocStackSamplingDepth());
                 ProfilerRuntimeObjLiveness.setRunGCOnGetResults(scipCmd.getRunGCOnGetResultsInMemoryProfiling());
-                Classes.setWaitTrackingEnabled(scipCmd.getWaitTrackingEnabled());
-                Classes.setSleepTrackingEnabled(scipCmd.getSleepTrackingEnabled());
+                threadSampling = scipCmd.isThreadsSamplingEnabled();
+                waitTracking = scipCmd.isWaitTrackingEnabled();
+                sleepTracking = scipCmd.isSleepTrackingEnabled();
+                Monitors.setThreadsSamplingEnabled(threadSampling);
+                ProfilerRuntimeCPU.setWaitAndSleepTracking(waitTracking,sleepTracking);
+                Classes.setWaitTrackingEnabled(threadSampling || waitTracking);
+                Classes.setSleepTrackingEnabled(threadSampling || sleepTracking);
                 sendSimpleResponseToClient(true, null);
 
                 break;
@@ -1584,8 +1582,8 @@ public class ProfilerServer extends Thread implements CommonConstants {
                                                                      System.getProperty("os.name"), // NOI18N
                                                                      Runtime.getRuntime().maxMemory(),
                                                                      System.currentTimeMillis(), Timers.getCurrentTimeInCounts(),
-                                                                     getAgentId() // NOI18N
-                ); // NOI18N
+                                                                     getAgentId()
+                );
                 sendComplexResponseToClient(resp);
 
                 break;
@@ -1674,7 +1672,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
     }
 
     private void handleIOExceptionOnSend(IOException ex) {
-        System.err.println(MessageFormat.format(RESPONSE_EXCEPTION_MSG, new Object[] { ex })); // NOI18N
+        System.err.println(MessageFormat.format(RESPONSE_EXCEPTION_MSG, new Object[] { ex }));
         ex.printStackTrace(System.err);
         closeConnection();
     }
@@ -1703,7 +1701,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
                 Object o = wireIO.receiveCommandOrResponse();
 
                 if (o == null) {
-                    System.err.println(CONNECTION_INTERRUPTED_MSG); // NOI18N
+                    System.err.println(CONNECTION_INTERRUPTED_MSG);
 
                     break; // end of connection
                 }
@@ -1716,7 +1714,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
                 }
             } catch (IOException ex) {
                 if (connectionOpen && !detachCommandReceived) { // It is not an asynchronous connection shutdown
-                    System.err.println(MessageFormat.format(COMMAND_EXCEPTION_MSG, new Object[] { ex })); // NOI18N
+                    System.err.println(MessageFormat.format(COMMAND_EXCEPTION_MSG, new Object[] { ex }));
                 }
 
                 break;
@@ -1730,7 +1728,7 @@ public class ProfilerServer extends Thread implements CommonConstants {
         try {
             getInfoFile(serverPort).delete();
         } catch (IOException e) {
-            System.err.println(MessageFormat.format(AGENT_ERROR_MSG, new Object[] { e.getMessage() })); // NOI18N
+            System.err.println(MessageFormat.format(AGENT_ERROR_MSG, new Object[] { e.getMessage() }));
         }
     }
 
