@@ -348,7 +348,7 @@ public abstract class AllocResultsPanel extends MemoryResultsPanel {
 
         for (int i = 0; i < columnNames.length; i++) {
             menuItem = new JCheckBoxMenuItem(columnNames[i]);
-            menuItem.setActionCommand(new Integer(i).toString());
+            menuItem.setActionCommand(Integer.valueOf(i).toString());
             addMenuItemListener(menuItem);
 
             if (resTable != null) {
