@@ -276,7 +276,7 @@ public final class LiveResultsWindow extends TopComponent
         }
     }
 
-    private final class MemoryActionsHandler implements MemoryResUserActionsHandler {
+    private static final class MemoryActionsHandler implements MemoryResUserActionsHandler {
         //~ Methods --------------------------------------------------------------------------------------------------------------
 
         public void showSourceForMethod(final String className, final String methodName, final String methodSig) {
@@ -460,9 +460,21 @@ public final class LiveResultsWindow extends TopComponent
     private volatile boolean profilerRunning = false;
     private volatile boolean resultsAvailable = false;
 
+    private static class Singleton {
+        final private static LiveResultsWindow INSTANCE = new LiveResultsWindow();
+    }
+    
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
     public LiveResultsWindow() {
+        IDEUtils.runInEventDispatchThreadAndWait(new Runnable() {
+            public void run() {
+                initUI();
+            }
+        });
+    }
+    
+    private void initUI() {
         setName(NbBundle.getMessage(LiveResultsWindow.class, "LAB_ResultsWindowName")); // NOI18N
         setIcon(liveWindowIcon);
         getAccessibleContext().setAccessibleDescription(LIVE_RESULTS_ACCESS_DESCR);
@@ -559,13 +571,9 @@ public final class LiveResultsWindow extends TopComponent
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
-    public static synchronized LiveResultsWindow getDefault() {
+    public static LiveResultsWindow getDefault() {
         if (!hasDefault()) {
-            IDEUtils.runInEventDispatchThreadAndWait(new Runnable() {
-                    public void run() {
-                        defaultLiveInstance = new LiveResultsWindow();
-                    }
-                });
+            defaultLiveInstance = Singleton.INSTANCE;
         }
 
         return defaultLiveInstance;
@@ -1060,7 +1068,7 @@ public final class LiveResultsWindow extends TopComponent
                         return;
                     }
 
-                    RequestProcessor.getDefault().post(new Runnable() {
+                    IDEUtils.runInProfilerRequestProcessor(new Runnable() {
                             public void run() {
                                 // send a command to server to generate the newest live data
                                 callForceObtainedResultsDump(runner.getProfilerClient());
