@@ -43,6 +43,10 @@
 
 package org.netbeans.modules.profiler;
 
+import com.sun.tools.attach.AgentInitializationException;
+import com.sun.tools.attach.AgentLoadException;
+import com.sun.tools.attach.AttachNotSupportedException;
+import com.sun.tools.attach.VirtualMachine;
 import org.netbeans.api.progress.ProgressHandle;
 import org.netbeans.api.progress.ProgressHandleFactory;
 import org.netbeans.lib.profiler.ProfilerClient;
@@ -113,8 +117,6 @@ import java.io.InputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
 import java.io.OutputStream;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
 import java.net.Socket;
 import java.net.SocketTimeoutException;
 import java.text.MessageFormat;
@@ -511,6 +513,8 @@ public final class NetBeansProfiler extends Profiler {
     private int profilingMode = MODE_PROFILE;
     private int profilingState = PROFILING_INACTIVE;
 
+    private final RequestProcessor srcOpenerRP = new RequestProcessor("Profiler Source Opener"); // NOI18N
+    
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
     public NetBeansProfiler() {
@@ -616,6 +620,8 @@ public final class NetBeansProfiler extends Profiler {
 
     // ---------------------------------------------------------------------------
     public static boolean isInitialized() {
+        // make sure that the profiler is initialized
+        getDefaultNB();
         return initialized;
     }
 
@@ -848,7 +854,7 @@ public final class NetBeansProfiler extends Profiler {
                         boolean success = false;
 
                         try {
-                            loadAgentIntTargetJVM(jar, options, pid);
+                            loadAgentIntoTargetJVM(jar, options, pid);
 
                             if (prepareInstrumentation(profilingSettings)) {
                                 success = targetAppRunner.initiateSession(2, false) && targetAppRunner.attachToTargetVM();
@@ -892,17 +898,10 @@ public final class NetBeansProfiler extends Profiler {
                     }
                 }
 
-                private void loadAgentIntTargetJVM(final String jar, final String options, final String pid)
-                                            throws SecurityException, IllegalArgumentException, IllegalAccessException,
-                                                   NoSuchMethodException, ClassNotFoundException, InvocationTargetException {
-                    //VirtualMachine virtualMachine = VirtualMachine attach(String id);
-                    Class vmClass = Class.forName("com.sun.tools.attach.VirtualMachine"); // NOI18N
-                    Method attachMethod = vmClass.getMethod("attach", String.class); // NOI18N
-                    Object virtualMachine = attachMethod.invoke(null, pid);
-
-                    // virtualMachine.loadAgent(jar,options);
-                    Method loadAgentMethod = vmClass.getMethod("loadAgent", String.class, String.class); // NOI18N
-                    loadAgentMethod.invoke(virtualMachine, jar, options);
+                private void loadAgentIntoTargetJVM(final String jar, final String options, final String pid)
+                                            throws AttachNotSupportedException, IOException, AgentLoadException, AgentInitializationException  {
+                    VirtualMachine virtualMachine = VirtualMachine.attach(pid);
+                    virtualMachine.loadAgent(jar,options);
                 }
 
                 @Override
@@ -1511,6 +1510,21 @@ public final class NetBeansProfiler extends Profiler {
                 displayInfoAndWait(INITIAL_CALIBRATION_MSG);
                 result = targetAppRunner.calibrateInstrumentationCode();
             }
+
+            boolean shouldCalibrate = false;
+            targetAppRunner.getProfilingSessionStatus().beginTrans(false);
+            try {
+                // the calibration was executed without the usage of "-XX:+UseLinuxPosixThreadCPUClocks" flag
+                // ---> recalibrate <---
+                shouldCalibrate = Platform.isLinux() &&
+                                  Platform.JDK_16_STRING.equals(pes.getTargetJDKVersionString()) &&
+                                  targetAppRunner.getProfilingSessionStatus().methodEntryExitCallTime[1] > 20000; // 20us
+            } finally {
+                targetAppRunner.getProfilingSessionStatus().endTrans();
+            }
+            if (shouldCalibrate) {
+                result = targetAppRunner.calibrateInstrumentationCode();
+            }
         } else {
             result = targetAppRunner.calibrateInstrumentationCode();
         }
@@ -1578,6 +1592,7 @@ public final class NetBeansProfiler extends Profiler {
     @Override
     public boolean prepareInstrumentation(ProfilingSettings profilingSettings) {
         final boolean retValue;
+
         teardownDispatcher();
         setupDispatcher(profilingSettings);
 
@@ -1997,10 +2012,10 @@ public final class NetBeansProfiler extends Profiler {
             ProfilerClient client = getTargetAppRunner().getProfilerClient();
 
             CCTResultsFilter filter = Lookup.getDefault().lookup(CCTResultsFilter.class);
-            filter.setEvaluators(Lookup.getDefault().lookupAll(CCTResultsFilter.EvaluatorProvider.class));
 
             if (filter != null) {
                 filter.reset(); // clean up the filter before reusing it
+                filter.setEvaluators(Lookup.getDefault().lookupAll(CCTResultsFilter.EvaluatorProvider.class));
             }
 
             // init context aware instances
