@@ -118,7 +118,6 @@ public final class ResultsManager {
     }
 
     //~ Static fields/initializers -----------------------------------------------------------------------------------------------
-    private static ResultsManager defaultResultsManager;
 
     // -----
     // I18N String constants
@@ -194,13 +193,14 @@ public final class ResultsManager {
     //~ Constructors -------------------------------------------------------------------------------------------------------------
     private ResultsManager() {}
 
+    private static class Singleton {
+        final private static ResultsManager INSTANCE = new ResultsManager();
+    }
+    
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
     public static ResultsManager getDefault() {
-        if (defaultResultsManager==null) {
-            defaultResultsManager=new ResultsManager();
-        }
-        return defaultResultsManager;
+        return Singleton.INSTANCE;
     }
 
     public String getDefaultSnapshotFileName(LoadedSnapshot ls) {
@@ -242,7 +242,7 @@ public final class ResultsManager {
         Integer type = typeCache.get(fo);
 
         if (type == null) {
-            type = new Integer(readTypeFromFile(fo));
+            type = Integer.valueOf(readTypeFromFile(fo));
             typeCache.put(fo, type);
         }
 
