@@ -84,6 +84,7 @@ public class OverviewController extends AbstractController {
     private static final String OPEN_THREADS_URL = "file:/stackframe/";     // NOI18N
     private static final String CLASS_URL_PREFIX = "file://class/"; // NOI18N
     private static final String INSTANCE_URL_PREFIX = "file://instance/";   // NOI18N
+    private static final String THREAD_URL_PREFIX = "file://thread/";   // NOI18N
 
     // -----
     // I18N String constants
@@ -113,12 +114,20 @@ public class OverviewController extends AbstractController {
             "OverviewController_GcRootsItemString"); // NOI18N
     private static final String FINALIZERS_ITEM_STRING = NbBundle.getMessage(OverviewController.class,
             "OverviewController_FinalizersItemString"); // NOI18N
+    private static final String OOME_LABEL_STRING = NbBundle.getMessage(OverviewController.class,
+            "OverviewController_OOMELabelString"); // NOI18N
+    private static final String OOME_ITEM_STRING = NbBundle.getMessage(OverviewController.class,
+            "OverviewController_OOMEItemString"); // NOI18N
     private static final String OS_ITEM_STRING = NbBundle.getMessage(OverviewController.class, 
             "OverviewController_OsItemString"); // NOI18N
     private static final String ARCHITECTURE_ITEM_STRING = NbBundle.getMessage(OverviewController.class,
             "OverviewController_ArchitectureItemString"); // NOI18N
     private static final String JAVA_HOME_ITEM_STRING = NbBundle.getMessage(OverviewController.class,
             "OverviewController_JavaHomeItemString"); // NOI18N
+    private static final String JAVA_VERSION_ITEM_STRING = NbBundle.getMessage(OverviewController.class,
+            "OverviewController_JavaVersionItemString"); // NOI18N
+    private static final String JAVA_VENDOR_ITEM_STRING = NbBundle.getMessage(OverviewController.class,
+            "OverviewController_JavaVendorItemString"); // NOI18N
     private static final String JVM_ITEM_STRING = NbBundle.getMessage(OverviewController.class,
             "OverviewController_JvmItemString"); // NOI18N
     private static final String SHOW_SYSPROPS_LINK_STRING = NbBundle.getMessage(OverviewController.class,
@@ -140,13 +149,13 @@ public class OverviewController extends AbstractController {
     private Properties systemProperties;
     private String stackTrace;
     private JavaClass java_lang_Class;
-
+    private ThreadObjectGCRoot oome;
+    
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
     public OverviewController(SummaryController summaryController) {
         this.summaryController = summaryController;
         heapFragmentWalker = summaryController.getHeapFragmentWalker();
-        java_lang_Class = heapFragmentWalker.getHeapFragment().getJavaClassByName(Class.class.getName());
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
@@ -178,7 +187,10 @@ public class OverviewController extends AbstractController {
         long finalizers = computeFinalizers(heap);
         int nclassloaders = 0;
         JavaClass cl = heap.getJavaClassByName("java.lang.ClassLoader"); // NOI18N
+        NumberFormat numberFormat = (NumberFormat)NumberFormat.getInstance().clone();
+        numberFormat.setMaximumFractionDigits(1);
         
+        oome = getOOMEThread(heap);
         if (cl != null) {
             nclassloaders = cl.getInstancesCount();
             
@@ -188,8 +200,6 @@ public class OverviewController extends AbstractController {
                 nclassloaders += jc.getInstancesCount();
             }
         }
-        NumberFormat numberFormat = (NumberFormat)NumberFormat.getInstance().clone();
-        numberFormat.setMaximumFractionDigits(1);
         
         String filename = "&nbsp;&nbsp;&nbsp;&nbsp;" // NOI18N
                 + MessageFormat.format(FILE_ITEM_STRING,
@@ -233,10 +243,20 @@ public class OverviewController extends AbstractController {
         String finalizersInfo = "&nbsp;&nbsp;&nbsp;&nbsp;" // NOI18N
                 + MessageFormat.format(FINALIZERS_ITEM_STRING,
                 new Object[] { numberFormat.format(finalizers) });
-        
+
+        String oomeString = "";
+        if (oome != null) {
+            Instance thread = oome.getInstance();
+            String threadName = htmlize(getThreadName(thread));
+            String threadUrl = "<a href='"+ THREAD_URL_PREFIX + thread.getJavaClass().getName() + "/" + thread.getInstanceId() + "'>" + threadName + "</a>"; // NOI18N
+            oomeString = "<br><br>&nbsp;&nbsp;&nbsp;&nbsp;" // NOI18N
+                + OOME_LABEL_STRING + "<br>&nbsp;&nbsp;&nbsp;&nbsp;"
+                + MessageFormat.format(OOME_ITEM_STRING,
+                new Object[] {  threadUrl });
+        }
         return "<b><img border='0' align='bottom' src='nbresloc:/org/netbeans/modules/profiler/resources/memory.png'>&nbsp;&nbsp;" // NOI18N
                 + SUMMARY_STRING + "</b><br><hr>" + dateTaken + "<br>" + filename + "<br>" + filesize + "<br><br>" + liveBytes // NOI18N
-                + "<br>" + liveClasses + "<br>" + liveInstances + "<br>" + classloaders + "<br>" + gcroots + "<br>" + finalizersInfo; // NOI18N
+                + "<br>" + liveClasses + "<br>" + liveInstances + "<br>" + classloaders + "<br>" + gcroots + "<br>" + finalizersInfo + oomeString; // NOI18N
     }
     
     public String computeEnvironment() {
@@ -265,6 +285,10 @@ public class OverviewController extends AbstractController {
         String jdk = "&nbsp;&nbsp;&nbsp;&nbsp;" // NOI18N
                 + MessageFormat.format(JAVA_HOME_ITEM_STRING,
                 new Object[] { sysprops.getProperty("java.home", NOT_AVAILABLE_MSG) }); // NOI18N
+
+        String version = "&nbsp;&nbsp;&nbsp;&nbsp;" // NOI18N
+                + MessageFormat.format(JAVA_VERSION_ITEM_STRING,
+                new Object[] { sysprops.getProperty("java.version", NOT_AVAILABLE_MSG) }); // NOI18N
         
         String jvm = "&nbsp;&nbsp;&nbsp;&nbsp;" // NOI18N
                 + MessageFormat.format(JVM_ITEM_STRING,
@@ -273,9 +297,13 @@ public class OverviewController extends AbstractController {
             sysprops.getProperty("java.vm.version", ""), // NOI18N
             sysprops.getProperty("java.vm.info", "") // NOI18N
         });
+
+        String vendor = "&nbsp;&nbsp;&nbsp;&nbsp;" // NOI18N
+                + MessageFormat.format(JAVA_VENDOR_ITEM_STRING,
+                new Object[] { sysprops.getProperty("java.vendor", NOT_AVAILABLE_MSG) }); // NOI18N
         
         return "<b><img border='0' align='bottom' src='nbresloc:/org/netbeans/modules/profiler/heapwalk/ui/resources/sysinfo.png'>&nbsp;&nbsp;" // NOI18N
-                + ENVIRONMENT_STRING + "</b><br><hr>" + os + "<br>" + arch + "<br>" + jdk + "<br>" + jvm; // NOI18N
+                + ENVIRONMENT_STRING + "</b><br><hr>" + os + "<br>" + arch + "<br>" + jdk + "<br>" + version + "<br>" + jvm + "<br>" + vendor; // NOI18N
     }
     
     public String computeSystemProperties(boolean showSystemProperties) {
@@ -310,36 +338,36 @@ public class OverviewController extends AbstractController {
             urls = urls.substring(INSTANCE_URL_PREFIX.length());
 
             String[] id = urls.split("/"); // NOI18N
-            JavaClass c = heapFragmentWalker.getHeapFragment().getJavaClassByName(id[0]);
+            long instanceId = Long.parseLong(id[2]);
+            Instance i = heapFragmentWalker.getHeapFragment().getInstanceByID(instanceId);
 
-            if (c != null) {
-                List<Instance> instances = c.getInstances();
-                Instance i = null;
-                int instanceNumber = Integer.parseInt(id[1]);
-                if (instanceNumber <= instances.size()) i = instances.get(instanceNumber - 1);
-
-                if (i != null) {
-                    heapFragmentWalker.getClassesController().showInstance(i);
-                } else {
-                    NetBeansProfiler.getDefaultNB()
-                            .displayError(MessageFormat.format(CANNOT_RESOLVE_INSTANCE_MSG,
-                            new Object[] { id[1], c.getName() }));
-                }
+            if (i != null) {
+                heapFragmentWalker.getClassesController().showInstance(i);
             } else {
                 NetBeansProfiler.getDefaultNB()
-                        .displayError(MessageFormat.format(CANNOT_RESOLVE_CLASS_MSG, new Object[] { id[0] }));
+                        .displayError(MessageFormat.format(CANNOT_RESOLVE_INSTANCE_MSG,
+                        new Object[] { id[1], id[0] }));
             }
         } else if (urls.startsWith(CLASS_URL_PREFIX)) {
             urls = urls.substring(CLASS_URL_PREFIX.length());
+            String[] id = urls.split("/"); // NOI18N
+            long jclsid = Long.parseLong(id[1]);
 
-            JavaClass c = heapFragmentWalker.getHeapFragment().getJavaClassByName(urls);
+            JavaClass c = heapFragmentWalker.getHeapFragment().getJavaClassByID(jclsid);
 
             if (c != null) {
                 heapFragmentWalker.getClassesController().showClass(c);
             } else {
-                NetBeansProfiler.getDefaultNB().displayError(MessageFormat.format(CANNOT_RESOLVE_CLASS_MSG, new Object[] { urls }));
+                NetBeansProfiler.getDefaultNB().displayError(MessageFormat.format(CANNOT_RESOLVE_CLASS_MSG, new Object[] { id[0] }));
             }
+        }   else if (urls.startsWith(THREAD_URL_PREFIX)) {
+            urls = urls.substring(THREAD_URL_PREFIX.length());
+            String[] id = urls.split("/"); // NOI18N
+            long threadid = Long.parseLong(id[1]);
+            
+            showInThreads(heapFragmentWalker.getHeapFragment().getInstanceByID(threadid));
         } 
+ 
     }
             
     private long computeFinalizers(Heap heap) {
@@ -356,6 +384,26 @@ public class OverviewController extends AbstractController {
         return -1;
     }
     
+    private ThreadObjectGCRoot getOOMEThread(Heap heap) {
+        Collection<GCRoot> roots = heap.getGCRoots();
+
+        for (GCRoot root : roots) {
+            if(root.getKind().equals(GCRoot.THREAD_OBJECT)) {
+                ThreadObjectGCRoot threadRoot = (ThreadObjectGCRoot)root;
+                StackTraceElement[] stackTrace = threadRoot.getStackTrace();
+                
+                if (stackTrace.length>=1) {
+                    StackTraceElement ste = stackTrace[0];
+                    
+                    if (OutOfMemoryError.class.getName().equals(ste.getClassName()) && "<init>".equals(ste.getMethodName())) {
+                        return threadRoot;
+                    }
+                }
+            }
+        }
+        return null;
+    }
+    
     private Properties getSystemProperties() {
         if (!systemPropertiesComputed) {
             systemProperties = heapFragmentWalker.getHeapFragment().getSystemProperties();
@@ -410,25 +458,23 @@ public class OverviewController extends AbstractController {
                     ThreadObjectGCRoot threadRoot = (ThreadObjectGCRoot)root;
                     Instance threadInstance = threadRoot.getInstance();
                     if (threadInstance != null) {
-                        PrimitiveArrayInstance chars = (PrimitiveArrayInstance)threadInstance.getValueOfField("name");  // NOI18N
-                        List<String> charsList = chars.getValues();
-                        char charArr[] = new char[charsList.size()];
-                        int j = 0;
-                        for(String ch: charsList) {
-                            charArr[j++] = ch.charAt(0);
-                        }
-                        String threadName = new String(charArr);
+                        String threadName = getThreadName(threadInstance);
                         Boolean daemon = (Boolean)threadInstance.getValueOfField("daemon"); // NOI18N
                         Integer priority = (Integer)threadInstance.getValueOfField("priority"); // NOI18N
                         Long threadId = (Long)threadInstance.getValueOfField("tid");    // NOI18N
                         Integer threadStatus = (Integer)threadInstance.getValueOfField("threadStatus"); // NOI18N
                         StackTraceElement stack[] = threadRoot.getStackTrace();
                         Map<Integer,List<JavaFrameGCRoot>> localsMap = javaFrameMap.get(threadRoot);
+                        String style="";
+
+                        if (threadRoot.equals(oome)) {
+                            style="style=\"color: #FF0000\"";
+                        }                        
                         // --- Use this to enable VisualVM color scheme for threads dumps: ---
                         // sw.append("&nbsp;&nbsp;<span style=\"color: #0033CC\">"); // NOI18N
-                        sb.append("&nbsp;&nbsp;<b>");   // NOI18N
+                        sb.append("&nbsp;&nbsp;<a name="+threadInstance.getInstanceId()+"></a><b "+style+">");   // NOI18N
                         // -------------------------------------------------------------------
-                        sb.append("\""+threadName+"\""+(daemon.booleanValue() ? " daemon" : "")+" prio="+priority);   // NOI18N
+                        sb.append("\""+htmlize(threadName)+"\""+(daemon.booleanValue() ? " daemon" : "")+" prio="+priority);   // NOI18N
                         if (threadId != null) {
                             sb.append(" tid="+threadId);    // NOI18N
                         }
@@ -454,7 +500,12 @@ public class OverviewController extends AbstractController {
                                     if (locals != null) {
                                         for (JavaFrameGCRoot localVar : locals) {
                                             Instance localInstance = localVar.getInstance();
-                                            sb.append("\t   Local Variable: "+printInstance(localInstance)+"<br>"); // NOI18N
+                                            
+                                            if (localInstance != null) {
+                                                sb.append("\t   Local Variable: "+printInstance(localInstance)+"<br>"); // NOI18N
+                                            } else {
+                                                sb.append("\t   Unknown Local Variable<br>"); // NOI18N                                                
+                                            }
                                         }
                                     }
                                 }
@@ -472,6 +523,18 @@ public class OverviewController extends AbstractController {
         return stackTrace;
     }
 
+    private String getThreadName(final Instance threadInstance) {
+        PrimitiveArrayInstance chars = (PrimitiveArrayInstance)threadInstance.getValueOfField("name");  // NOI18N
+        List<String> charsList = chars.getValues();
+        char charArr[] = new char[charsList.size()];
+        int j = 0;
+        
+        for(String ch: charsList) {
+            charArr[j++] = ch.charAt(0);
+        }
+        return new String(charArr);
+    }
+
 
     private Map<ThreadObjectGCRoot,Map<Integer,List<JavaFrameGCRoot>>> computeJavaFrameMap(Collection<GCRoot> roots) {
         Map<ThreadObjectGCRoot,Map<Integer,List<JavaFrameGCRoot>>> javaFrameMap = new HashMap();
@@ -501,14 +564,28 @@ public class OverviewController extends AbstractController {
 
     private String printInstance(Instance in) {
         String className;
+        JavaClass jcls = in.getJavaClass();
         
-        if (in.getJavaClass().equals(java_lang_Class)) {
-            JavaClass javaClass = heapFragmentWalker.getHeapFragment().getJavaClassByID(in.getInstanceId());
-            className = javaClass.getName();
-            return "<a href='"+ CLASS_URL_PREFIX + className + "' name='" + javaClass.getJavaClassId() + "'>class " + className + "</a>"; // NOI18N
+        if (jcls == null) {
+            return "unknown instance #"+in.getInstanceId(); // NOI18N
         }
-        className = in.getJavaClass().getName();
-        return "<a href='"+ INSTANCE_URL_PREFIX + className + "/" + in.getInstanceNumber() + "' name='" + in.getInstanceId() + "'>" + className + '#' + in.getInstanceNumber() + "</a>"; // NOI18N
+        if (jcls.equals(getJavaClass())) {
+            JavaClass javaClass = heapFragmentWalker.getHeapFragment().getJavaClassByID(in.getInstanceId());
+            
+            if (javaClass != null) {
+                className = javaClass.getName();
+                return "<a href='"+ CLASS_URL_PREFIX + className + "/" + javaClass.getJavaClassId() + "'>class " + className + "</a>"; // NOI18N
+            }
+        }
+        className = jcls.getName();
+        return "<a href='"+ INSTANCE_URL_PREFIX + className + "/" + in.getInstanceNumber() + "/" + in.getInstanceId() + "' name='" + in.getInstanceId() + "'>" + className + '#' + in.getInstanceNumber() + "</a>"; // NOI18N
+    }
+
+    private JavaClass getJavaClass() {
+        if (java_lang_Class == null) {
+            java_lang_Class = heapFragmentWalker.getHeapFragment().getJavaClassByName(Class.class.getName());
+        }
+        return java_lang_Class;
     }
 
     private static String htmlize(String value) {
