@@ -277,6 +277,7 @@ public class ClassesListControllerUI extends JTitledPanel {
     private CardLayout contents;
     private ClassesListController classesListController;
     private final NumberFormat percentFormat = NumberFormat.getPercentInstance();
+    private final NumberFormat numberFormat = NumberFormat.getInstance();
     private ClassesListTableModel realClassesListTableModel = new ClassesListTableModel();
     private ExtendedTableModel classesListTableModel = new ExtendedTableModel(realClassesListTableModel);
     private FilterComponent filterComponent;
@@ -418,7 +419,7 @@ public class ClassesListControllerUI extends JTitledPanel {
 
         for (int i = 0; i < realClassesListTableModel.getColumnCount(); i++) {
             menuItem = new JCheckBoxMenuItem(realClassesListTableModel.getColumnName(i));
-            menuItem.setActionCommand(new Integer(i).toString());
+            menuItem.setActionCommand(Integer.valueOf(i).toString());
             addMenuItemListener(menuItem);
 
             if (classesListTable != null) {
@@ -776,11 +777,11 @@ public class ClassesListControllerUI extends JTitledPanel {
                             displayCache2[i][0] = jClass.getName();
                             displayCache2[i][1] = new Double((double) instancesCount /
                                                  (double) totalLiveInstances * 100);
-                            displayCache2[i][2] = Integer.toString(instancesCount) + " (" // NOI18N
+                            displayCache2[i][2] = numberFormat.format(instancesCount) + " (" // NOI18N
                                                  + percentFormat.format((double) instancesCount /
                                                  (double) totalLiveInstances) + ")"; // NOI18N
                             displayCache2[i][3] = (allInstancesSize < 0) ? RESULT_NOT_AVAILABLE_STRING
-                                                  : (Long.toString(allInstancesSize) + " (" // NOI18N
+                                                  : (numberFormat.format(allInstancesSize) + " (" // NOI18N
                                                   + percentFormat.format((double) allInstancesSize /
                                                   (double) totalLiveBytes) + ")"); // NOI18N
                             displayCache2[i][4] = jClass;
@@ -849,7 +850,6 @@ public class ClassesListControllerUI extends JTitledPanel {
     }
 
     private void showSubclassesForClass(JavaClass jClass) {
-        filterComponent.setFilterType(ClassesListController.FILTER_SUBCLASS);
-        filterComponent.setFilterString(jClass.getName()); // fires change in filterComponent
+        filterComponent.setFilterValues(jClass.getName(),ClassesListController.FILTER_SUBCLASS);
     }
 }
