@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -45,7 +48,6 @@ import org.netbeans.modules.profiler.ProfilerIDESettings;
 import org.netbeans.modules.profiler.heapwalk.HeapFragmentWalker;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
-import org.openide.util.Utilities;
 import java.awt.BorderLayout;
 import java.awt.CardLayout;
 import java.awt.Component;
@@ -59,6 +61,7 @@ import javax.swing.Action;
 import javax.swing.ImageIcon;
 import javax.swing.JPanel;
 import javax.swing.JToolBar;
+import org.netbeans.modules.profiler.oql.engine.api.OQLEngine;
 
 
 /**
@@ -81,19 +84,21 @@ public class HeapFragmentWalkerUI extends JPanel {
                                                                                                                            // -----
 
     // --- UI definition ---------------------------------------------------------
-    private static ImageIcon ICON_BACK = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/heapwalk/ui/resources/back.png")); // NOI18N
-    private static ImageIcon ICON_FORWARD = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/heapwalk/ui/resources/forward.png")); // NOI18N
+    private static ImageIcon ICON_BACK = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/heapwalk/ui/resources/back.png", false); // NOI18N
+    private static ImageIcon ICON_FORWARD = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/heapwalk/ui/resources/forward.png", false); // NOI18N
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
     private AbstractAction backAction;
     private AbstractAction forwardAction;
+    private AbstractButton oqlControllerPresenter;
     private AbstractButton analysisControllerPresenter;
     private AbstractButton classesControllerPresenter;
     private AbstractButton instancesControllerPresenter;
     private AbstractButton summaryControllerPresenter;
     private CardLayout controllerUIsLayout;
     private HeapFragmentWalker heapFragmentWalker;
+    private JPanel oqlControllerPanel;
     private JPanel analysisControllerPanel;
     private JPanel classesControllerPanel;
     private JPanel controllerUIsPanel;
@@ -101,6 +106,7 @@ public class HeapFragmentWalkerUI extends JPanel {
     private JPanel summaryControllerPanel;
     private JToolBar toolBar;
     private boolean analysisEnabled;
+    private boolean oqlEnabled;
     private int subControllersIndex;
 
     //~ Constructors -------------------------------------------------------------------------------------------------------------
@@ -111,6 +117,7 @@ public class HeapFragmentWalkerUI extends JPanel {
 
         ProfilerIDESettings pis = ProfilerIDESettings.getInstance();
         analysisEnabled = pis.getHeapWalkerAnalysisEnabled();
+        oqlEnabled = OQLEngine.isOQLSupported();
 
         initComponents();
         updateNavigationActions();
@@ -118,7 +125,13 @@ public class HeapFragmentWalkerUI extends JPanel {
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
+    public boolean isOQLViewActive() {
+        if (oqlControllerPanel == null) return false;
+        return oqlControllerPanel.isShowing();
+    }
+
     public boolean isAnalysisViewActive() {
+        if (analysisControllerPanel == null) return false;
         return analysisControllerPanel.isShowing();
     }
 
@@ -135,6 +148,10 @@ public class HeapFragmentWalkerUI extends JPanel {
         return summaryControllerPanel.isShowing();
     }
 
+    public void showOQLView() {
+        showOQLView(true);
+    }
+
     public void showAnalysisView() {
         showAnalysisView(true);
     }
@@ -143,6 +160,10 @@ public class HeapFragmentWalkerUI extends JPanel {
         showClassesView(true);
     }
 
+    public void showHistoryOQLView() {
+        showOQLView(false);
+    }
+
     public void showHistoryAnalysisView() {
         showAnalysisView(false);
     }
@@ -199,6 +220,9 @@ public class HeapFragmentWalkerUI extends JPanel {
         summaryControllerPanel = heapFragmentWalker.getSummaryController().getPanel();
         classesControllerPanel = heapFragmentWalker.getClassesController().getPanel();
         instancesControllerPanel = heapFragmentWalker.getInstancesController().getPanel();
+        if (oqlEnabled) {
+            oqlControllerPanel = heapFragmentWalker.getOQLController().getPanel();
+        }
 
         if (analysisEnabled) {
             analysisControllerPanel = heapFragmentWalker.getAnalysisController().getPanel();
@@ -208,6 +232,10 @@ public class HeapFragmentWalkerUI extends JPanel {
         classesControllerPresenter = heapFragmentWalker.getClassesController().getPresenter();
         instancesControllerPresenter = heapFragmentWalker.getInstancesController().getPresenter();
 
+        if (oqlEnabled) {
+            oqlControllerPresenter = heapFragmentWalker.getOQLController().getPresenter();
+        }
+
         if (analysisEnabled) {
             analysisControllerPresenter = heapFragmentWalker.getAnalysisController().getPresenter();
         }
@@ -241,6 +269,10 @@ public class HeapFragmentWalkerUI extends JPanel {
             toolBar.add(analysisControllerPresenter);
         }
 
+        if (oqlEnabled) {
+            toolBar.add(oqlControllerPresenter);
+        }
+
         JPanel toolBarFiller = new JPanel(new FlowLayout(FlowLayout.LEADING, 0, 0)) {
             public Dimension getPreferredSize() {
                 if (UIUtils.isGTKLookAndFeel() || UIUtils.isNimbusLookAndFeel()) {
@@ -268,6 +300,10 @@ public class HeapFragmentWalkerUI extends JPanel {
             controllerUIsPanel.add(analysisControllerPanel, analysisControllerPresenter.getText());
         }
 
+        if (oqlEnabled) {
+            controllerUIsPanel.add(oqlControllerPanel, oqlControllerPresenter.getText());
+        }
+
         add(toolBar, BorderLayout.NORTH);
         add(controllerUIsPanel, BorderLayout.CENTER);
 
@@ -279,23 +315,24 @@ public class HeapFragmentWalkerUI extends JPanel {
             analysisControllerPresenter.setSelected(false);
         }
 
+        if (oqlEnabled) {
+            oqlControllerPresenter.setSelected(false);
+        }
+
         summaryControllerPresenter.addActionListener(new ActionListener() {
                 public void actionPerformed(ActionEvent e) {
                     showSummaryView();
                 }
-                ;
             });
         classesControllerPresenter.addActionListener(new ActionListener() {
                 public void actionPerformed(ActionEvent e) {
                     showClassesView();
                 }
-                ;
             });
         instancesControllerPresenter.addActionListener(new ActionListener() {
                 public void actionPerformed(ActionEvent e) {
                     showInstancesView();
                 }
-                ;
             });
 
         if (analysisEnabled) {
@@ -303,9 +340,15 @@ public class HeapFragmentWalkerUI extends JPanel {
                     public void actionPerformed(ActionEvent e) {
                         showAnalysisView();
                     }
-                    ;
                 });
+        }
 
+        if (oqlEnabled) {
+            oqlControllerPresenter.addActionListener(new ActionListener() {
+                    public void actionPerformed(ActionEvent e) {
+                        showOQLView();
+                    }
+                });
         }
 
         // Classes view shown by default
@@ -313,18 +356,20 @@ public class HeapFragmentWalkerUI extends JPanel {
         summaryControllerPresenter.setSelected(true);
 
         // support for traversing subtabs using Ctrl-Alt-PgDn/PgUp
-        getActionMap().put("PreviousViewAction",
+        getActionMap().put("PreviousViewAction", // NOI18N
                            new AbstractAction() {
                 public void actionPerformed(ActionEvent e) {
                     moveToPreviousView();
+                    updatePresentersFocus();
                 }
-            }); // NOI18N
-        getActionMap().put("NextViewAction",
+            });
+        getActionMap().put("NextViewAction", // NOI18N
                            new AbstractAction() {
                 public void actionPerformed(ActionEvent e) {
                     moveToNextView();
+                    updatePresentersFocus();
                 }
-            }); // NOI18N
+            });
     }
 
     private void moveToNextView() {
@@ -335,16 +380,32 @@ public class HeapFragmentWalkerUI extends JPanel {
         } else if (isInstancesViewActive()) {
             if (analysisEnabled) {
                 showAnalysisView();
+            } else if (oqlEnabled) {
+                showOQLView();
             } else {
                 showSummaryView();
             }
         } else if (isAnalysisViewActive()) {
+            if (oqlEnabled) {
+                showOQLView();
+            } else {
+                showSummaryView();
+            }
+        } else if (isOQLViewActive()) {
             showSummaryView();
         }
     }
 
     private void moveToPreviousView() {
         if (isSummaryViewActive()) {
+            if (oqlEnabled) {
+                showOQLView();
+            } else if (analysisEnabled) {
+                showAnalysisView();
+            } else {
+                showInstancesView();
+            }
+        } else if (isOQLViewActive()) {
             if (analysisEnabled) {
                 showAnalysisView();
             } else {
@@ -359,6 +420,19 @@ public class HeapFragmentWalkerUI extends JPanel {
         }
     }
 
+    private void showOQLView(boolean addToHistory) {
+        if (!isOQLViewActive()) {
+            if (addToHistory) {
+                heapFragmentWalker.createNavigationHistoryPoint();
+            }
+
+            controllerUIsLayout.show(controllerUIsPanel, oqlControllerPresenter.getText());
+            updateClientPresenters(heapFragmentWalker.getOQLController().getClientPresenters());
+        }
+
+        updatePresenters();
+    }
+
     private void showAnalysisView(boolean addToHistory) {
         if (!isAnalysisViewActive()) {
             if (addToHistory) {
@@ -439,5 +513,21 @@ public class HeapFragmentWalkerUI extends JPanel {
         if (analysisEnabled) {
             analysisControllerPresenter.setSelected(analysisControllerPanel.isShowing());
         }
+        if (oqlEnabled) {
+            oqlControllerPresenter.setSelected(oqlControllerPanel.isShowing());
+        }
+    }
+
+    private void updatePresentersFocus() {
+        if (summaryControllerPresenter.isSelected())
+            summaryControllerPresenter.requestFocus();
+        else if (classesControllerPresenter.isSelected())
+            classesControllerPresenter.requestFocus();
+        else if (instancesControllerPresenter.isSelected())
+            instancesControllerPresenter.requestFocus();
+        else if (analysisEnabled && analysisControllerPresenter.isSelected())
+            analysisControllerPresenter.requestFocus();
+        else if (oqlEnabled && oqlControllerPresenter.isSelected())
+            oqlControllerPresenter.requestFocus();
     }
 }
