@@ -1,7 +1,10 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
+ *
+ * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
+ * Other names may be trademarks of their respective owners.
  *
  * The contents of this file are subject to the terms of either the GNU
  * General Public License Version 2 only ("GPL") or the Common
@@ -13,9 +16,9 @@
  * specific language governing permissions and limitations under the
  * License.  When distributing the software, include this License Header
  * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
+ * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Sun in the GPL Version 2 section of the License file that
+ * by Oracle in the GPL Version 2 section of the License file that
  * accompanied this code. If applicable, add the following below the
  * License Header, with the fields enclosed by brackets [] replaced by
  * your own identifying information:
@@ -40,6 +43,7 @@
 
 package org.netbeans.modules.profiler.heapwalk.ui;
 
+import java.awt.datatransfer.Transferable;
 import org.netbeans.lib.profiler.heap.Instance;
 import org.netbeans.lib.profiler.heap.JavaClass;
 import org.netbeans.lib.profiler.ui.UIConstants;
@@ -51,16 +55,22 @@ import org.netbeans.lib.profiler.ui.components.treetable.AbstractTreeTableModel;
 import org.netbeans.lib.profiler.ui.components.treetable.ExtendedTreeTableModel;
 import org.netbeans.lib.profiler.ui.components.treetable.JTreeTablePanel;
 import org.netbeans.lib.profiler.ui.components.treetable.TreeTableModel;
+import org.netbeans.modules.profiler.heapwalk.HeapFragmentWalker.StateEvent;
 import org.netbeans.modules.profiler.heapwalk.InstancesListController;
 import org.netbeans.modules.profiler.heapwalk.model.HeapWalkerNode;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
-import org.openide.util.Utilities;
 import java.awt.BorderLayout;
 import java.awt.Dimension;
+import java.awt.Font;
 import java.awt.Insets;
 import java.awt.KeyboardFocusManager;
 import java.awt.Rectangle;
+import java.awt.datatransfer.Clipboard;
+import java.awt.datatransfer.ClipboardOwner;
+import java.awt.datatransfer.StringSelection;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
 import java.awt.event.InputEvent;
 import java.awt.event.KeyAdapter;
 import java.awt.event.KeyEvent;
@@ -72,6 +82,7 @@ import javax.swing.ImageIcon;
 import javax.swing.JButton;
 import javax.swing.JCheckBoxMenuItem;
 import javax.swing.JLabel;
+import javax.swing.JMenuItem;
 import javax.swing.JPanel;
 import javax.swing.JPopupMenu;
 import javax.swing.JScrollPane;
@@ -83,6 +94,9 @@ import javax.swing.event.ListSelectionListener;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableColumnModel;
 import javax.swing.tree.TreePath;
+import org.netbeans.modules.profiler.heapwalk.HeapFragmentWalker;
+import org.openide.util.Lookup;
+import org.openide.util.RequestProcessor;
 
 
 /**
@@ -92,6 +106,46 @@ import javax.swing.tree.TreePath;
 public class InstancesListControllerUI extends JTitledPanel {
     //~ Inner Classes ------------------------------------------------------------------------------------------------------------
 
+    private class InstancesListTableKeyListener extends KeyAdapter {
+        //~ Methods --------------------------------------------------------------------------------------------------------------
+
+        public void keyPressed(KeyEvent e) {
+            if ((e.getKeyCode() == KeyEvent.VK_CONTEXT_MENU)
+                    || ((e.getKeyCode() == KeyEvent.VK_F10) && (e.getModifiers() == InputEvent.SHIFT_MASK))) {
+                int selectedRow = instancesListTable.getSelectedRow();
+
+                if (selectedRow != -1) {
+                    Rectangle rowBounds = instancesListTable.getCellRect(selectedRow, 0, true);
+                    tablePopup.show(instancesListTable, rowBounds.x + (rowBounds.width / 2), rowBounds.y + (rowBounds.height / 2));
+                }
+            } else if (KeyStroke.getAWTKeyStroke(e.getKeyCode(), e.getModifiers()).equals(COPY_ID_KEYSTROKE)) {
+                copyIdToClipboard();
+            }
+        }
+    }
+    
+    private class InstancesListTableMouseListener extends MouseAdapter {
+        //~ Methods --------------------------------------------------------------------------------------------------------------
+
+        private void updateSelection(int row) {
+            instancesListTable.requestFocusInWindow();
+            if (row != -1) instancesListTable.setRowSelectionInterval(row, row);
+            else instancesListTable.clearSelection();
+        }
+
+        public void mousePressed(final MouseEvent e) {
+            final int row = instancesListTable.rowAtPoint(e.getPoint());
+            updateSelection(row);
+            if (e.isPopupTrigger()) tablePopup.show(e.getComponent(), e.getX(), e.getY());
+        }
+
+        public void mouseReleased(MouseEvent e) {
+            int row = instancesListTable.rowAtPoint(e.getPoint());
+            updateSelection(row);
+            if (e.isPopupTrigger()) tablePopup.show(e.getComponent(), e.getX(), e.getY());
+        }
+    }
+    
     // --- TreeTable model -------------------------------------------------------
     private class InstancesListTreeTableModel extends AbstractTreeTableModel {
         //~ Constructors ---------------------------------------------------------------------------------------------------------
@@ -147,11 +201,15 @@ public class InstancesListControllerUI extends JTitledPanel {
                     case 0:
                         return node;
                     case 1:
+                        return "0x" + Long.toHexString(node.getID());
+                    case 2:
                         return node.getSize();
+                    case 3:
+                        return node.getRetainedSize();
+
+                    // TODO: uncomment once reachable size implemented
+                    //          case 4: return node.getReachableSize();
 
-                    // TODO: uncomment once retained & reachable size implemented
-                    //          case 2: return node.getRetainedSize();
-                    //          case 3: return node.getReachableSize();
                     default:
                         return null;
                 }
@@ -208,6 +266,10 @@ public class InstancesListControllerUI extends JTitledPanel {
                                                                            "InstancesListControllerUI_InstanceColumnName"); // NOI18N
     private static final String INSTANCE_COLUMN_DESCR = NbBundle.getMessage(InstancesListControllerUI.class,
                                                                             "InstancesListControllerUI_InstanceColumnDescr"); // NOI18N
+    private static final String OBJID_COLUMN_NAME = NbBundle.getMessage(InstancesListControllerUI.class,
+                                                                           "InstancesListControllerUI_ObjidColumnName"); // NOI18N
+    private static final String OBJID_COLUMN_DESCR = NbBundle.getMessage(InstancesListControllerUI.class,
+                                                                            "InstancesListControllerUI_ObjidColumnDescr"); // NOI18N
     private static final String SIZE_COLUMN_NAME = NbBundle.getMessage(InstancesListControllerUI.class,
                                                                        "InstancesListControllerUI_SizeColumnName"); // NOI18N
     private static final String SIZE_COLUMN_DESCR = NbBundle.getMessage(InstancesListControllerUI.class,
@@ -220,9 +282,12 @@ public class InstancesListControllerUI extends JTitledPanel {
                                                                                  "InstancesListControllerUI_ReachableSizeColumnName"); // NOI18N
     private static final String REACHABLE_SIZE_COLUMN_DESCR = NbBundle.getMessage(InstancesListControllerUI.class,
                                                                                   "InstancesListControllerUI_ReachableSizeColumnDescr"); // NOI18N
-                                                                                                                                         // -----
-    private static ImageIcon ICON_INSTANCES = new ImageIcon(ImageUtilities.loadImage("org/netbeans/modules/profiler/heapwalk/ui/resources/instances.png")); // NOI18N
-    private static final int columnCount = 2; // TODO: restore back to 4 once retained & reachable size implemented
+    private static final String COPY_ID_STRING = NbBundle.getMessage(InstancesListControllerUI.class,
+                                                                               "InstancesListControllerUI_CopyIdString"); // NOI18N
+// -----
+    private static KeyStroke COPY_ID_KEYSTROKE = KeyStroke.getKeyStroke(KeyEvent.VK_C, InputEvent.ALT_DOWN_MASK + InputEvent.CTRL_DOWN_MASK);
+    private static ImageIcon ICON_INSTANCES = ImageUtilities.loadImageIcon("org/netbeans/modules/profiler/heapwalk/ui/resources/instances.png", false); // NOI18N
+    private int columnCount;
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
@@ -232,8 +297,11 @@ public class InstancesListControllerUI extends JTitledPanel {
     private InstancesListController instancesListController;
     private InstancesListTreeTableModel realInstancesListModel;
 
+    private boolean retainedSizeSupported;
+
     // --- UI definition ---------------------------------------------------------
     private JPanel dataPanel;
+    private JPopupMenu tablePopup;
     private JPopupMenu cornerPopup;
     private JTreeTable instancesListTable;
     private String filterValue = ""; // NOI18N
@@ -249,7 +317,7 @@ public class InstancesListControllerUI extends JTitledPanel {
     private boolean sorting = false;
     private boolean sortingOrder = false;
     private int selectedRow;
-    private int sortingColumn = 1;
+    private int sortingColumn = 2;
 
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
@@ -259,12 +327,37 @@ public class InstancesListControllerUI extends JTitledPanel {
 
         this.instancesListController = instancesListController;
 
+        retainedSizeSupported = instancesListController.getInstancesController().
+                                getHeapFragmentWalker().getRetainedSizesStatus() !=
+                                HeapFragmentWalker.RETAINED_SIZES_UNSUPPORTED;
+        columnCount = retainedSizeSupported ? 4 : 3;
+
         realInstancesListModel = new InstancesListTreeTableModel();
         instancesListTableModel = new ExtendedTreeTableModel(realInstancesListModel);
 
         initColumnsData();
         initData();
         initComponents();
+
+        instancesListController.getInstancesController().
+            getHeapFragmentWalker().addStateListener(
+                new HeapFragmentWalker.StateListener() {
+                    public void stateChanged(StateEvent e) {
+                        if (e.getRetainedSizesStatus() == HeapFragmentWalker.
+                            RETAINED_SIZES_COMPUTED && e.isMasterChange()) {
+                                SwingUtilities.invokeLater(new Runnable() {
+                                    public void run() {
+                                        instancesListTableModel.
+                                                setRealColumnVisibility(3, true);
+                                        instancesListTable.createDefaultColumnsFromModel();
+                                        instancesListTable.updateTreeTableHeader();
+                                        setColumnsData();
+                                    }
+                                });
+                        }
+                    }
+                }
+            );
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
@@ -276,14 +369,17 @@ public class InstancesListControllerUI extends JTitledPanel {
                         JavaClass selectedClass = instancesListController.getInstancesController().getSelectedClass();
 
                         if ((selectedClass != null) && selectedClass.isArray()) {
-                            if (!instancesListTableModel.isRealColumnVisible(1)) {
-                                toggleColumnVisibility(1, false);
+                            if (!instancesListTableModel.isRealColumnVisible(2)) {
+                                toggleColumnVisibility(2, false);
                             }
                         } else {
-                            if (instancesListTableModel.isRealColumnVisible(1)) {
-                                toggleColumnVisibility(1, false);
+                            if (instancesListTableModel.isRealColumnVisible(2)) {
+                                toggleColumnVisibility(2, false);
                             }
                         }
+                        if (instancesListTableModel.isRealColumnVisible(1)) {
+                            toggleColumnVisibility(1, false); // objectid is not visible as default
+                        }
                     }
                 });
         }
@@ -354,7 +450,7 @@ public class InstancesListControllerUI extends JTitledPanel {
 
         for (int i = 0; i < realInstancesListModel.getColumnCount(); i++) {
             menuItem = new JCheckBoxMenuItem(realInstancesListModel.getColumnName(i));
-            menuItem.setActionCommand(new Integer(i).toString());
+            menuItem.setActionCommand(Integer.valueOf(i).toString());
             addMenuItemListener(menuItem);
 
             if (instancesListTable != null) {
@@ -388,16 +484,40 @@ public class InstancesListControllerUI extends JTitledPanel {
         }
     }
 
-    private void addMenuItemListener(JCheckBoxMenuItem menuItem) {
+    private void addMenuItemListener(final JCheckBoxMenuItem menuItem) {
+        final boolean[] internalChange = new boolean[1];
         menuItem.addActionListener(new java.awt.event.ActionListener() {
-                public void actionPerformed(java.awt.event.ActionEvent e) {
-                    toggleColumnVisibility(Integer.parseInt(e.getActionCommand()), true);
+            public void actionPerformed(java.awt.event.ActionEvent e) {
+                if (internalChange[0]) return;
+                final int column = Integer.parseInt(e.getActionCommand());
+                if (column == 3 && !instancesListTableModel.isRealColumnVisible(column)) {
+                    RequestProcessor.getDefault().post(new Runnable() {
+                        public void run() {
+                            final int retainedSizesState = instancesListController.getInstancesController().
+                                    getHeapFragmentWalker().computeRetainedSizes(false);
+                            SwingUtilities.invokeLater(new Runnable() {
+                                public void run() {
+                                    if (retainedSizesState != HeapFragmentWalker.RETAINED_SIZES_COMPUTED) {
+                                        internalChange[0] = true;
+                                        menuItem.setSelected(!menuItem.isSelected());
+                                        internalChange[0] = false;
+                                    } else {
+                                        toggleColumnVisibility(column, true);
+                                    }
+                                }
+                            });
+                        }
+                    });
+                } else {
+                    toggleColumnVisibility(column, true);
                 }
-            });
+
+            }
+        });
     }
 
     private JButton createHeaderPopupCornerButton(final JPopupMenu headerPopup) {
-        final JButton cornerButton = new JButton(new ImageIcon(ImageUtilities.loadImage("org/netbeans/lib/profiler/ui/resources/hideColumn.png"))); // NOI18N
+        final JButton cornerButton = new JButton(ImageUtilities.loadImageIcon("org/netbeans/lib/profiler/ui/resources/hideColumn.png", false)); // NOI18N
         cornerButton.setToolTipText(SHOW_HIDE_COLUMNS_STRING);
         cornerButton.setDefaultCapable(false);
 
@@ -440,7 +560,36 @@ public class InstancesListControllerUI extends JTitledPanel {
 
         return cornerButton;
     }
+    
+    private JPopupMenu createTablePopup() {
+        JPopupMenu popup = new JPopupMenu();
+        
+        JMenuItem copyIdItem = new JMenuItem(COPY_ID_STRING);
+        copyIdItem.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent e) {
+                copyIdToClipboard();
+            }
+        });
+        copyIdItem.setAccelerator(COPY_ID_KEYSTROKE);
+//        copyIdItem.setFont(popup.getFont().deriveFont(Font.BOLD));
 
+        popup.add(copyIdItem);
+
+        return popup;
+    }
+
+    private void copyIdToClipboard() {
+        Clipboard clipboard = Lookup.getDefault().lookup(Clipboard.class);
+
+        clipboard.setContents(new StringSelection("0x" + Long.toHexString(instancesListController.getSelectedInstance().getInstanceId())), new ClipboardOwner() {
+
+            @Override
+            public void lostOwnership(Clipboard clipboard, Transferable contents) {
+                // ignore
+            }
+        });
+    }
+    
     private boolean displaysCollapsedInstances() {
         HeapWalkerNode root = (HeapWalkerNode) instancesListTableModel.getRoot();
 
@@ -464,13 +613,18 @@ public class InstancesListControllerUI extends JTitledPanel {
         columnNames[0] = INSTANCE_COLUMN_NAME;
         columnToolTips[0] = INSTANCE_COLUMN_DESCR;
 
-        columnNames[1] = SIZE_COLUMN_NAME;
-        columnToolTips[1] = SIZE_COLUMN_DESCR;
+        columnNames[1] = OBJID_COLUMN_NAME;
+        columnToolTips[1] = OBJID_COLUMN_DESCR;
+        
+        columnNames[2] = SIZE_COLUMN_NAME;
+        columnToolTips[2] = SIZE_COLUMN_DESCR;
 
-        // TODO: uncomment once retained & reachable size implemented
-        //    columnNames[2] = RETAINED_SIZE_COLUMN_NAME;
-        //    columnToolTips[2] = RETAINED_SIZE_COLUMN_DESCR;
-        //
+        if (retainedSizeSupported) {
+            columnNames[3] = RETAINED_SIZE_COLUMN_NAME;
+            columnToolTips[3] = RETAINED_SIZE_COLUMN_DESCR;
+        }
+
+        // TODO: uncomment once reachable size implemented
         //    columnNames[3] = REACHABLE_SIZE_COLUMN_NAME;
         //    columnToolTips[3] = REACHABLE_SIZE_COLUMN_DESCR;
         int maxWidth = getFontMetrics(getFont()).charWidth('W') * 7; // NOI18N // initial width of data columns
@@ -485,13 +639,18 @@ public class InstancesListControllerUI extends JTitledPanel {
         // method / class / package name
         columnRenderers[0] = null;
 
-        columnWidths[1 - 1] = maxWidth;
-        columnRenderers[1] = dataCellRenderer;
+        // objectid
+        columnRenderers[1] = null;
+        
+        columnWidths[2 - 2] = maxWidth;
+        columnRenderers[2] = dataCellRenderer;
 
-        // TODO: uncomment once retained & reachable size implemented
-        //    columnWidths[2 - 1] = maxWidth;
-        //    columnRenderers[2] = dataCellRenderer;
-        //    
+        if (retainedSizeSupported) {
+            columnWidths[3 - 2] = maxWidth;
+            columnRenderers[3] = dataCellRenderer;
+        }
+        
+        // TODO: uncomment once reachable size implemented
         //    columnWidths[3 - 1] = maxWidth;
         //    columnRenderers[3] = dataCellRenderer;
     }
@@ -501,8 +660,12 @@ public class InstancesListControllerUI extends JTitledPanel {
         treeCellRenderer.setClosedIcon(null);
         treeCellRenderer.setOpenIcon(null);
 
+        if (retainedSizeSupported)
+            instancesListTableModel.setRealColumnVisibility(3, instancesListController.
+                getInstancesController().getHeapFragmentWalker().getRetainedSizesStatus()
+                                          == HeapFragmentWalker.RETAINED_SIZES_COMPUTED);
+        
         // TODO: uncomment once retained & reachable size implemented
-        //    instancesListTableModel.setRealColumnVisibility(2, false);
         //    instancesListTableModel.setRealColumnVisibility(3, false);
         instancesListTable = new JTreeTable(instancesListTableModel) {
                 public void doLayout() {
@@ -528,6 +691,8 @@ public class InstancesListControllerUI extends JTitledPanel {
                 ;
             };
         instancesListTable.getTree().setRootVisible(false);
+        instancesListTable.addMouseListener(new InstancesListTableMouseListener());
+        instancesListTable.addKeyListener(new InstancesListTableKeyListener());
         instancesListTable.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
         instancesListTable.setGridColor(UIConstants.TABLE_VERTICAL_GRID_COLOR);
         instancesListTable.setSelectionBackground(UIConstants.TABLE_SELECTION_BACKGROUND_COLOR);
@@ -536,6 +701,7 @@ public class InstancesListControllerUI extends JTitledPanel {
         instancesListTable.setShowVerticalLines(UIConstants.SHOW_TABLE_VERTICAL_GRID);
         instancesListTable.setRowMargin(UIConstants.TABLE_ROW_MARGIN);
         instancesListTable.setRowHeight(UIUtils.getDefaultRowHeight() + 2);
+        instancesListTable.getTree().setLargeModel(true);
 
         // Disable traversing table cells using TAB and Shift+TAB
         Set keys = new HashSet(instancesListTable.getFocusTraversalKeys(KeyboardFocusManager.FORWARD_TRAVERSAL_KEYS));
@@ -548,7 +714,7 @@ public class InstancesListControllerUI extends JTitledPanel {
 
         setColumnsData();
 
-        //    tablePopup = createTablePopup();
+        tablePopup = createTablePopup();
         cornerPopup = new JPopupMenu();
 
         JTreeTablePanel tablePanel = new JTreeTablePanel(instancesListTable);
@@ -656,6 +822,7 @@ public class InstancesListControllerUI extends JTitledPanel {
     }
 
     private void toggleColumnVisibility(int column, boolean reSort) {
+
         boolean sortResults = false;
         int currentSortingColumn = instancesListTable.getSortingColumn();
         int realSortingColumn = instancesListTableModel.getRealColumn(currentSortingColumn);
