@@ -430,7 +430,7 @@ public class ReferencesBrowserControllerUI extends JTitledPanel {
 
         for (int i = 0; i < realFieldsListTableModel.getColumnCount(); i++) {
             menuItem = new JCheckBoxMenuItem(realFieldsListTableModel.getColumnName(i));
-            menuItem.setActionCommand(new Integer(i).toString());
+            menuItem.setActionCommand(Integer.valueOf(i).toString());
             addMenuItemListener(menuItem);
 
             if (fieldsListTable != null) {
