@@ -46,13 +46,13 @@ package org.netbeans.modules.profiler.ui.stp;
 import org.netbeans.lib.profiler.client.ClientUtils;
 import org.netbeans.lib.profiler.common.ProfilingSettings;
 import org.netbeans.lib.profiler.common.ProfilingSettingsPresets;
-import org.netbeans.lib.profiler.global.Platform;
 import org.openide.filesystems.FileObject;
 import java.util.Properties;
 import java.util.Vector;
 import javax.swing.JPanel;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
+import org.netbeans.lib.profiler.TargetAppRunner;
 
 
 /**
@@ -65,7 +65,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
     public static class CPUContents implements SettingsContainerPanel.Contents, ChangeListener {
         //~ Static fields/initializers -------------------------------------------------------------------------------------------
 
-        private static final boolean ENABLE_THREAD_CPU_TIMER = Boolean.getBoolean("org.netbeans.lib.profiler.enableThreadCPUTimer"); // NOI18N
+//        private static final boolean ENABLE_THREAD_CPU_TIMER = Boolean.getBoolean("org.netbeans.lib.profiler.enableThreadCPUTimer"); // NOI18N
 
         //~ Instance fields ------------------------------------------------------------------------------------------------------
 
@@ -79,7 +79,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
         private boolean isAttach;
         private boolean isModify;
         private boolean isPreset;
-        private boolean useCPUTimer;
+        final private static boolean useCPUTimer = true; // always enabled
 
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
@@ -107,8 +107,6 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
             this.enableOverride = enableOverride;
             this.isAttach = isAttach;
             this.isModify = isModify;
-
-            useCPUTimer = ENABLE_THREAD_CPU_TIMER || isAttach || Platform.isSolaris();
         }
 
         public float getProfilingOverhead() {
@@ -158,6 +156,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
             advancedSettingsPanel.setProfileFramework(settings.getProfileUnderlyingFramework());
 
             advancedSettingsPanel.setThreadsMonitoring(settings.getThreadsMonitoringEnabled());
+            advancedSettingsPanel.setThreadsSampling(settings.getThreadsSamplingEnabled());
             advancedSettingsPanel.setOverrideAvailable(enableOverride);
             advancedSettingsPanel.setOverrideSettings(settings.getOverrideGlobalSettings());
             advancedSettingsPanel.setWorkingDirectory(settings.getWorkingDir());
@@ -205,6 +204,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
             finalSettings.setNProfiledThreadsLimit(advancedSettingsPanel.getProfiledThreadsLimit());
 
             finalSettings.setThreadsMonitoringEnabled(advancedSettingsPanel.getThreadsMonitoring());
+            finalSettings.setThreadsSamplingEnabled(advancedSettingsPanel.getThreadsSampling());
             finalSettings.setOverrideGlobalSettings(advancedSettingsPanel.getOverrideSettings());
             finalSettings.setWorkingDir(advancedSettingsPanel.getWorkingDirectory());
             finalSettings.setJavaPlatformName(advancedSettingsPanel.getJavaPlatformName());
@@ -233,7 +233,6 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
             isAttach = false;
             isModify = false;
             isPreset = false;
-            useCPUTimer = false;
         }
 
         public void stateChanged(ChangeEvent e) {
@@ -275,6 +274,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
             settings.setNProfiledThreadsLimit(advancedSettingsPanel.getProfiledThreadsLimit());
 
             settings.setThreadsMonitoringEnabled(advancedSettingsPanel.getThreadsMonitoring());
+            settings.setThreadsSamplingEnabled(advancedSettingsPanel.getThreadsSampling());
             settings.setOverrideGlobalSettings(advancedSettingsPanel.getOverrideSettings());
             settings.setWorkingDir(advancedSettingsPanel.getWorkingDirectory());
             settings.setJavaPlatformName(advancedSettingsPanel.getJavaPlatformName());
@@ -371,6 +371,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
             advancedSettingsPanel.setRunGC(settings.getRunGCOnGetResultsInMemoryProfiling());
 
             advancedSettingsPanel.setThreadsMonitoring(settings.getThreadsMonitoringEnabled());
+            advancedSettingsPanel.setThreadsSampling(settings.getThreadsSamplingEnabled());
             advancedSettingsPanel.setOverrideAvailable(enableOverride);
             advancedSettingsPanel.setOverrideSettings(settings.getOverrideGlobalSettings());
             advancedSettingsPanel.setWorkingDirectory(settings.getWorkingDir());
@@ -409,6 +410,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
             finalSettings.setRunGCOnGetResultsInMemoryProfiling(advancedSettingsPanel.getRunGC());
 
             finalSettings.setThreadsMonitoringEnabled(advancedSettingsPanel.getThreadsMonitoring());
+            finalSettings.setThreadsSamplingEnabled(advancedSettingsPanel.getThreadsSampling());
             finalSettings.setOverrideGlobalSettings(advancedSettingsPanel.getOverrideSettings());
             finalSettings.setWorkingDir(advancedSettingsPanel.getWorkingDirectory());
             finalSettings.setJavaPlatformName(advancedSettingsPanel.getJavaPlatformName());
@@ -455,6 +457,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
             settings.setRunGCOnGetResultsInMemoryProfiling(advancedSettingsPanel.getRunGC());
 
             settings.setThreadsMonitoringEnabled(advancedSettingsPanel.getThreadsMonitoring());
+            settings.setThreadsSamplingEnabled(advancedSettingsPanel.getThreadsSampling());
             settings.setOverrideGlobalSettings(advancedSettingsPanel.getOverrideSettings());
             settings.setWorkingDir(advancedSettingsPanel.getWorkingDirectory());
             settings.setJavaPlatformName(advancedSettingsPanel.getJavaPlatformName());
@@ -533,6 +536,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
 
             // basicSettingsPanel
             basicSettingsPanel.setThreadsMonitoring(settings.getThreadsMonitoringEnabled());
+            basicSettingsPanel.setThreadsSampling(settings.getThreadsSamplingEnabled());
 
             // advancedSettingsPanel
             if (!settings.isPreset()) {
@@ -568,6 +572,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
 
             // basicSettingsPanel
             finalSettings.setThreadsMonitoringEnabled(basicSettingsPanel.getThreadsMonitoring());
+            finalSettings.setThreadsSamplingEnabled(basicSettingsPanel.getThreadsSampling());
 
             // advancedSettingsPanel
             finalSettings.setOverrideGlobalSettings(advancedSettingsPanel.getOverrideSettings());
@@ -603,6 +608,7 @@ public class DefaultSettingsConfigurator implements SelectProfilingTask.Settings
 
             // basicSettingsPanel
             settings.setThreadsMonitoringEnabled(basicSettingsPanel.getThreadsMonitoring());
+            settings.setThreadsSamplingEnabled(basicSettingsPanel.getThreadsSampling());
 
             // advancedSettingsPanel
             settings.setOverrideGlobalSettings(advancedSettingsPanel.getOverrideSettings());
